/*-*- mode:c;indent-tabs-mode:nil;c-basic-offset:2;tab-width:8;coding:utf-8 -*-│
│vi: set net ft=c ts=2 sts=2 sw=2 fenc=utf-8                                :vi│
╞══════════════════════════════════════════════════════════════════════════════╡
│ Copyright 2021 Justine Alexandra Roberts Tunney                              │
│                                                                              │
│ Permission to use, copy, modify, and/or distribute this software for         │
│ any purpose with or without fee is hereby granted, provided that the         │
│ above copyright notice and this permission notice appear in all copies.      │
│                                                                              │
│ THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL                │
│ WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED                │
│ WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE             │
│ AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL         │
│ DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR        │
│ PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER               │
│ TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR             │
│ PERFORMANCE OF THIS SOFTWARE.                                                │
╚─────────────────────────────────────────────────────────────────────────────*/
#include "libc/macros.internal.h"
#include "libc/str/str.h"
#include "libc/dce.h"

static const char16_t kLowerToUpper[][2] = {
    {u'ß', u'ẞ'},      // 00df → 1e9e
    {u'à', u'À'},      // 00e0 → 00c0
    {u'á', u'Á'},      // 00e1 → 00c1
    {u'â', u'Â'},      // 00e2 → 00c2
    {u'ã', u'Ã'},      // 00e3 → 00c3
    {u'ä', u'Ä'},      // 00e4 → 00c4
    {u'å', u'Å'},      // 00e5 → 00c5
    {u'æ', u'Æ'},      // 00e6 → 00c6
    {u'ç', u'Ç'},      // 00e7 → 00c7
    {u'è', u'È'},      // 00e8 → 00c8
    {u'é', u'É'},      // 00e9 → 00c9
    {u'ê', u'Ê'},      // 00ea → 00ca
    {u'ë', u'Ë'},      // 00eb → 00cb
    {u'ì', u'Ì'},      // 00ec → 00cc
    {u'í', u'Í'},      // 00ed → 00cd
    {u'î', u'Î'},      // 00ee → 00ce
    {u'ï', u'Ï'},      // 00ef → 00cf
    {u'ð', u'Ð'},      // 00f0 → 00d0
    {u'ñ', u'Ñ'},      // 00f1 → 00d1
    {u'ò', u'Ò'},      // 00f2 → 00d2
    {u'ó', u'Ó'},      // 00f3 → 00d3
    {u'ô', u'Ô'},      // 00f4 → 00d4
    {u'õ', u'Õ'},      // 00f5 → 00d5
    {u'ö', u'Ö'},      // 00f6 → 00d6
    {u'ø', u'Ø'},      // 00f8 → 00d8
    {u'ù', u'Ù'},      // 00f9 → 00d9
    {u'ú', u'Ú'},      // 00fa → 00da
    {u'û', u'Û'},      // 00fb → 00db
    {u'ü', u'Ü'},      // 00fc → 00dc
    {u'ý', u'Ý'},      // 00fd → 00dd
    {u'þ', u'Þ'},      // 00fe → 00de
    {u'ÿ', u'Ÿ'},      // 00ff → 0178
#ifndef TINY
    {u'ā', u'Ā'},      // 0101 → 0100
    {u'ă', u'Ă'},      // 0103 → 0102
    {u'ą', u'Ą'},      // 0105 → 0104
    {u'ć', u'Ć'},      // 0107 → 0106
    {u'ĉ', u'Ĉ'},      // 0109 → 0108
    {u'ċ', u'Ċ'},      // 010b → 010a
    {u'č', u'Č'},      // 010d → 010c
    {u'ď', u'Ď'},      // 010f → 010e
    {u'đ', u'Đ'},      // 0111 → 0110
    {u'ē', u'Ē'},      // 0113 → 0112
    {u'ĕ', u'Ĕ'},      // 0115 → 0114
    {u'ė', u'Ė'},      // 0117 → 0116
    {u'ę', u'Ę'},      // 0119 → 0118
    {u'ě', u'Ě'},      // 011b → 011a
    {u'ĝ', u'Ĝ'},      // 011d → 011c
    {u'ğ', u'Ğ'},      // 011f → 011e
    {u'ġ', u'Ġ'},      // 0121 → 0120
    {u'ģ', u'Ģ'},      // 0123 → 0122
    {u'ĥ', u'Ĥ'},      // 0125 → 0124
    {u'ħ', u'Ħ'},      // 0127 → 0126
    {u'ĩ', u'Ĩ'},      // 0129 → 0128
    {u'ī', u'Ī'},      // 012b → 012a
    {u'ĭ', u'Ĭ'},      // 012d → 012c
    {u'į', u'Į'},      // 012f → 012e
    {u'ĳ', u'Ĳ'},      // 0133 → 0132
    {u'ĵ', u'Ĵ'},      // 0135 → 0134
    {u'ķ', u'Ķ'},      // 0137 → 0136
    {u'ĺ', u'Ĺ'},      // 013a → 0139
    {u'ļ', u'Ļ'},      // 013c → 013b
    {u'ľ', u'Ľ'},      // 013e → 013d
    {u'ŀ', u'Ŀ'},      // 0140 → 013f
    {u'ł', u'Ł'},      // 0142 → 0141
    {u'ń', u'Ń'},      // 0144 → 0143
    {u'ņ', u'Ņ'},      // 0146 → 0145
    {u'ň', u'Ň'},      // 0148 → 0147
    {u'ŋ', u'Ŋ'},      // 014b → 014a
    {u'ō', u'Ō'},      // 014d → 014c
    {u'ŏ', u'Ŏ'},      // 014f → 014e
    {u'ő', u'Ő'},      // 0151 → 0150
    {u'œ', u'Œ'},      // 0153 → 0152
    {u'ŕ', u'Ŕ'},      // 0155 → 0154
    {u'ŗ', u'Ŗ'},      // 0157 → 0156
    {u'ř', u'Ř'},      // 0159 → 0158
    {u'ś', u'Ś'},      // 015b → 015a
    {u'ŝ', u'Ŝ'},      // 015d → 015c
    {u'ş', u'Ş'},      // 015f → 015e
    {u'š', u'Š'},      // 0161 → 0160
    {u'ţ', u'Ţ'},      // 0163 → 0162
    {u'ť', u'Ť'},      // 0165 → 0164
    {u'ŧ', u'Ŧ'},      // 0167 → 0166
    {u'ũ', u'Ũ'},      // 0169 → 0168
    {u'ū', u'Ū'},      // 016b → 016a
    {u'ŭ', u'Ŭ'},      // 016d → 016c
    {u'ů', u'Ů'},      // 016f → 016e
    {u'ű', u'Ű'},      // 0171 → 0170
    {u'ų', u'Ų'},      // 0173 → 0172
    {u'ŵ', u'Ŵ'},      // 0175 → 0174
    {u'ŷ', u'Ŷ'},      // 0177 → 0176
    {u'ź', u'Ź'},      // 017a → 0179
    {u'ż', u'Ż'},      // 017c → 017b
    {u'ž', u'Ž'},      // 017e → 017d
    {u'ƀ', u'Ƀ'},      // 0180 → 0243
    {u'ƃ', u'Ƃ'},      // 0183 → 0182
    {u'ƅ', u'Ƅ'},      // 0185 → 0184
    {u'ƈ', u'Ƈ'},      // 0188 → 0187
    {u'ƌ', u'Ƌ'},      // 018c → 018b
    {u'ƒ', u'Ƒ'},      // 0192 → 0191
    {u'ƙ', u'Ƙ'},      // 0199 → 0198
    {u'ƚ', u'Ƚ'},      // 019a → 023d
    {u'ƞ', u'Ƞ'},      // 019e → 0220
    {u'ơ', u'Ơ'},      // 01a1 → 01a0
    {u'ƣ', u'Ƣ'},      // 01a3 → 01a2
    {u'ƥ', u'Ƥ'},      // 01a5 → 01a4
    {u'ƨ', u'Ƨ'},      // 01a8 → 01a7
    {u'ƭ', u'Ƭ'},      // 01ad → 01ac
    {u'ư', u'Ư'},      // 01b0 → 01af
    {u'ƴ', u'Ƴ'},      // 01b4 → 01b3
    {u'ƶ', u'Ƶ'},      // 01b6 → 01b5
    {u'ƹ', u'Ƹ'},      // 01b9 → 01b8
    {u'ƹ', u'Ʒ'},      // 01b9 → 01b7
    {u'ƽ', u'Ƽ'},      // 01bd → 01bc
    {u'ǆ', u'Ǳ'},      // 01c6 → 01f1
    {u'ǆ', u'Ǆ'},      // 01c6 → 01c4
    {u'ǉ', u'Ǉ'},      // 01c9 → 01c7
    {u'ǌ', u'Ǌ'},      // 01cc → 01ca
    {u'ǎ', u'Ǎ'},      // 01ce → 01cd
    {u'ǐ', u'Ǐ'},      // 01d0 → 01cf
    {u'ǒ', u'Ǒ'},      // 01d2 → 01d1
    {u'ǔ', u'Ǔ'},      // 01d4 → 01d3
    {u'ǖ', u'Ǖ'},      // 01d6 → 01d5
    {u'ǘ', u'Ǘ'},      // 01d8 → 01d7
    {u'ǚ', u'Ǚ'},      // 01da → 01d9
    {u'ǜ', u'Ǜ'},      // 01dc → 01db
    {u'ǟ', u'Ǟ'},      // 01df → 01de
    {u'ǡ', u'Ȧ'},      // 01e1 → 0226
    {u'ǡ', u'Ǡ'},      // 01e1 → 01e0
    {u'ǣ', u'Ǣ'},      // 01e3 → 01e2
    {u'ǥ', u'Ǥ'},      // 01e5 → 01e4
    {u'ǧ', u'Ǧ'},      // 01e7 → 01e6
    {u'ǩ', u'Ǩ'},      // 01e9 → 01e8
    {u'ǫ', u'Ǫ'},      // 01eb → 01ea
    {u'ǭ', u'Ǭ'},      // 01ed → 01ec
    {u'ǯ', u'Ǯ'},      // 01ef → 01ee
    {u'ǵ', u'Ǵ'},      // 01f5 → 01f4
    {u'ǹ', u'Ǹ'},      // 01f9 → 01f8
    {u'ǻ', u'Ǻ'},      // 01fb → 01fa
    {u'ǽ', u'Ǽ'},      // 01fd → 01fc
    {u'ǿ', u'Ǿ'},      // 01ff → 01fe
    {u'ȁ', u'Ȁ'},      // 0201 → 0200
    {u'ȃ', u'Ȃ'},      // 0203 → 0202
    {u'ȅ', u'Ȅ'},      // 0205 → 0204
    {u'ȇ', u'Ȇ'},      // 0207 → 0206
    {u'ȉ', u'Ȉ'},      // 0209 → 0208
    {u'ȋ', u'Ȋ'},      // 020b → 020a
    {u'ȍ', u'Ȍ'},      // 020d → 020c
    {u'ȏ', u'Ȏ'},      // 020f → 020e
    {u'ȑ', u'Ȑ'},      // 0211 → 0210
    {u'ȓ', u'Ȓ'},      // 0213 → 0212
    {u'ȕ', u'Ȕ'},      // 0215 → 0214
    {u'ȗ', u'Ȗ'},      // 0217 → 0216
    {u'ș', u'Ș'},      // 0219 → 0218
    {u'ț', u'Ț'},      // 021b → 021a
    {u'ȝ', u'Ȝ'},      // 021d → 021c
    {u'ȟ', u'Ȟ'},      // 021f → 021e
    {u'ȣ', u'Ȣ'},      // 0223 → 0222
    {u'ȥ', u'Ȥ'},      // 0225 → 0224
    {u'ȩ', u'Ȩ'},      // 0229 → 0228
    {u'ȫ', u'Ȫ'},      // 022b → 022a
    {u'ȭ', u'Ȭ'},      // 022d → 022c
    {u'ȯ', u'Ȯ'},      // 022f → 022e
    {u'ȱ', u'Ȱ'},      // 0231 → 0230
    {u'ȳ', u'Ȳ'},      // 0233 → 0232
    {u'ȼ', u'Ȼ'},      // 023c → 023b
    {u'ȿ', u'Ȿ'},      // 023f → 2c7e
    {u'ɀ', u'Ɀ'},      // 0240 → 2c7f
    {u'ɂ', u'Ɂ'},      // 0242 → 0241
    {u'ɇ', u'Ɇ'},      // 0247 → 0246
    {u'ɉ', u'Ɉ'},      // 0249 → 0248
    {u'ɍ', u'Ɍ'},      // 024d → 024c
    {u'ɏ', u'Ɏ'},      // 024f → 024e
    {u'ɐ', u'Ɐ'},      // 0250 → 2c6f
    {u'ɑ', u'Ɑ'},      // 0251 → 2c6d
    {u'ɒ', u'Ɒ'},      // 0252 → 2c70
    {u'ɓ', u'Ɓ'},      // 0253 → 0181
    {u'ɔ', u'Ɔ'},      // 0254 → 0186
    {u'ɗ', u'Ɗ'},      // 0257 → 018a
    {u'ɘ', u'Ǝ'},      // 0258 → 018e
    {u'ə', u'Ə'},      // 0259 → 018f
    {u'ɛ', u'Ɛ'},      // 025b → 0190
    {u'ɜ', u'Ɜ'},    // 025c → a7ab
    {u'ɠ', u'Ɠ'},      // 0260 → 0193
    {u'ɡ', u'Ɡ'},    // 0261 → a7ac
    {u'ɣ', u'Ɣ'},      // 0263 → 0194
    {u'ɥ', u'Ɥ'},      // 0265 → a78d
    {u'ɦ', u'Ɦ'},      // 0266 → a7aa
    {u'ɨ', u'Ɨ'},      // 0268 → 0197
    {u'ɩ', u'Ɩ'},      // 0269 → 0196
    {u'ɫ', u'Ɫ'},      // 026b → 2c62
    {u'ɬ', u'Ɬ'},    // 026c → a7ad
    {u'ɯ', u'Ɯ'},      // 026f → 019c
    {u'ɱ', u'Ɱ'},      // 0271 → 2c6e
    {u'ɲ', u'Ɲ'},      // 0272 → 019d
    {u'ɽ', u'Ɽ'},      // 027d → 2c64
    {u'ʂ', u'Ʂ'},    // 0282 → a7c5
    {u'ʃ', u'Ʃ'},      // 0283 → 01a9
    {u'ʇ', u'Ʇ'},    // 0287 → a7b1
    {u'ʈ', u'Ʈ'},      // 0288 → 01ae
    {u'ʉ', u'Ʉ'},      // 0289 → 0244
    {u'ʊ', u'Ʊ'},      // 028a → 01b1
    {u'ʋ', u'Ʋ'},      // 028b → 01b2
    {u'ʌ', u'Ʌ'},      // 028c → 0245
    {u'ʝ', u'Ʝ'},    // 029d → a7b2
    {u'ʞ', u'Ʞ'},    // 029e → a7b0
    {u'ͱ', u'Ͱ'},      // 0371 → 0370
    {u'ͳ', u'Ͳ'},      // 0373 → 0372
    {u'ͷ', u'Ͷ'},      // 0377 → 0376
    {u'ͻ', u'Ͻ'},      // 037b → 03fd
    {u'ͼ', u'Ͼ'},      // 037c → 03fe
    {u'ͽ', u'Ͽ'},      // 037d → 03ff
    {u'ΐ', u'Ι'},      // 0390 → 0399
    {u'ΐ', u'Ϊ'},      // 0390 → 03aa
    {u'ά', u'Α'},      // 03ac → 0391
    {u'ά', u'Ά'},      // 03ac → 0386
    {u'έ', u'Έ'},      // 03ad → 0388
    {u'έ', u'Ε'},      // 03ad → 0395
    {u'ή', u'Η'},      // 03ae → 0397
    {u'ή', u'Ή'},      // 03ae → 0389
    {u'ί', u'Ί'},      // 03af → 038a
    {u'ΰ', u'Υ'},      // 03b0 → 03a5
    {u'ΰ', u'Ϋ'},      // 03b0 → 03ab
    {u'β', u'Β'},      // 03b2 → 0392
    {u'γ', u'Γ'},      // 03b3 → 0393
    {u'δ', u'Δ'},      // 03b4 → 0394
    {u'ζ', u'Ζ'},      // 03b6 → 0396
    {u'θ', u'Θ'},      // 03b8 → 0398
    {u'κ', u'Κ'},      // 03ba → 039a
    {u'λ', u'Λ'},      // 03bb → 039b
    {u'μ', u'Μ'},      // 03bc → 039c
    {u'ν', u'Ν'},      // 03bd → 039d
    {u'ξ', u'Ξ'},      // 03be → 039e
    {u'ο', u'Ο'},      // 03bf → 039f
    {u'π', u'Π'},      // 03c0 → 03a0
    {u'ρ', u'Ρ'},      // 03c1 → 03a1
    {u'σ', u'Σ'},      // 03c3 → 03a3
    {u'τ', u'Τ'},      // 03c4 → 03a4
    {u'φ', u'Φ'},      // 03c6 → 03a6
    {u'χ', u'Χ'},      // 03c7 → 03a7
    {u'ψ', u'Ψ'},      // 03c8 → 03a8
    {u'ω', u'Ω'},      // 03c9 → 03a9
    {u'ό', u'Ό'},      // 03cc → 038c
    {u'ύ', u'Ύ'},      // 03cd → 038e
    {u'ώ', u'Ώ'},      // 03ce → 038f
    {u'ϣ', u'Ϣ'},      // 03e3 → 03e2
    {u'ϥ', u'Ϥ'},      // 03e5 → 03e4
    {u'ϧ', u'Ϧ'},      // 03e7 → 03e6
    {u'ϩ', u'Ϩ'},      // 03e9 → 03e8
    {u'ϫ', u'Ϫ'},      // 03eb → 03ea
    {u'ϭ', u'Ϭ'},      // 03ed → 03ec
    {u'ϯ', u'Ϯ'},      // 03ef → 03ee
    {u'ϸ', u'Ϸ'},      // 03f8 → 03f7
    {u'ϻ', u'Ϻ'},      // 03fb → 03fa
    {u'а', u'А'},      // 0430 → 0410
    {u'б', u'Б'},      // 0431 → 0411
    {u'в', u'В'},      // 0432 → 0412
    {u'г', u'Г'},      // 0433 → 0413
    {u'д', u'Д'},      // 0434 → 0414
    {u'е', u'Е'},      // 0435 → 0415
    {u'е', u'И'},      // 0435 → 0418
    {u'ж', u'Ж'},      // 0436 → 0416
    {u'з', u'З'},      // 0437 → 0417
    {u'й', u'Й'},      // 0439 → 0419
    {u'к', u'К'},      // 043a → 041a
    {u'л', u'Л'},      // 043b → 041b
    {u'л', u'Э'},      // 043b → 042d
    {u'м', u'М'},      // 043c → 041c
    {u'н', u'Н'},      // 043d → 041d
    {u'о', u'О'},      // 043e → 041e
    {u'п', u'П'},      // 043f → 041f
    {u'р', u'Р'},      // 0440 → 0420
    {u'с', u'С'},      // 0441 → 0421
    {u'т', u'Т'},      // 0442 → 0422
    {u'у', u'У'},      // 0443 → 0423
    {u'ф', u'Ф'},      // 0444 → 0424
    {u'х', u'Х'},      // 0445 → 0425
    {u'ц', u'Ц'},      // 0446 → 0426
    {u'ч', u'Ч'},      // 0447 → 0427
    {u'ш', u'Ш'},      // 0448 → 0428
    {u'щ', u'Щ'},      // 0449 → 0429
    {u'ъ', u'Ъ'},      // 044a → 042a
    {u'ы', u'Ы'},      // 044b → 042b
    {u'ь', u'Ь'},      // 044c → 042c
    {u'ю', u'Ю'},      // 044e → 042e
    {u'я', u'Я'},      // 044f → 042f
    {u'ѐ', u'Ѐ'},      // 0450 → 0400
    {u'ё', u'Ё'},      // 0451 → 0401
    {u'ђ', u'Ђ'},      // 0452 → 0402
    {u'ѓ', u'Ѓ'},      // 0453 → 0403
    {u'є', u'Ѹ'},      // 0454 → 0478
    {u'є', u'Є'},      // 0454 → 0404
    {u'ѕ', u'Ѕ'},      // 0455 → 0405
    {u'і', u'І'},      // 0456 → 0406
    {u'ї', u'Ї'},      // 0457 → 0407
    {u'ј', u'Ј'},      // 0458 → 0408
    {u'љ', u'Љ'},      // 0459 → 0409
    {u'њ', u'Њ'},      // 045a → 040a
    {u'ћ', u'Ћ'},      // 045b → 040b
    {u'ќ', u'Ќ'},      // 045c → 040c
    {u'ѝ', u'Ѝ'},      // 045d → 040d
    {u'ў', u'Ў'},      // 045e → 040e
    {u'џ', u'Џ'},      // 045f → 040f
    {u'ѡ', u'Ѡ'},      // 0461 → 0460
    {u'ѣ', u'Ѣ'},      // 0463 → 0462
    {u'ѥ', u'Ѥ'},      // 0465 → 0464
    {u'ѧ', u'Ѧ'},      // 0467 → 0466
    {u'ѩ', u'Ѩ'},      // 0469 → 0468
    {u'ѫ', u'Ѫ'},      // 046b → 046a
    {u'ѭ', u'Ѭ'},      // 046d → 046c
    {u'ѯ', u'Ѯ'},      // 046f → 046e
    {u'ѱ', u'Ѱ'},      // 0471 → 0470
    {u'ѳ', u'Ѳ'},      // 0473 → 0472
    {u'ѵ', u'Ѵ'},      // 0475 → 0474
    {u'ѷ', u'Ѷ'},      // 0477 → 0476
    {u'ѻ', u'Ѻ'},      // 047b → 047a
    {u'ѽ', u'Ѽ'},      // 047d → 047c
    {u'ѿ', u'Ѿ'},      // 047f → 047e
    {u'ҁ', u'Ҁ'},      // 0481 → 0480
    {u'ҋ', u'Ҋ'},      // 048b → 048a
    {u'ҍ', u'Ҍ'},      // 048d → 048c
    {u'ҏ', u'Ҏ'},      // 048f → 048e
    {u'ґ', u'Ґ'},      // 0491 → 0490
    {u'ғ', u'Ғ'},      // 0493 → 0492
    {u'ҕ', u'Ҕ'},      // 0495 → 0494
    {u'җ', u'Җ'},      // 0497 → 0496
    {u'ҙ', u'Ҙ'},      // 0499 → 0498
    {u'қ', u'Қ'},      // 049b → 049a
    {u'ҝ', u'Ҝ'},      // 049d → 049c
    {u'ҟ', u'Ҟ'},      // 049f → 049e
    {u'ҡ', u'Ҡ'},      // 04a1 → 04a0
    {u'ң', u'Ң'},      // 04a3 → 04a2
    {u'ҥ', u'Ҥ'},      // 04a5 → 04a4
    {u'ҧ', u'Ҧ'},      // 04a7 → 04a6
    {u'ҩ', u'Ҩ'},      // 04a9 → 04a8
    {u'ҫ', u'Ҫ'},      // 04ab → 04aa
    {u'ҭ', u'Ҭ'},      // 04ad → 04ac
    {u'ү', u'Ү'},      // 04af → 04ae
    {u'ұ', u'Ұ'},      // 04b1 → 04b0
    {u'ҳ', u'Ҳ'},      // 04b3 → 04b2
    {u'ҵ', u'Ҵ'},      // 04b5 → 04b4
    {u'ҷ', u'Ҷ'},      // 04b7 → 04b6
    {u'ҹ', u'Ҹ'},      // 04b9 → 04b8
    {u'һ', u'Һ'},      // 04bb → 04ba
    {u'ҽ', u'Ҽ'},      // 04bd → 04bc
    {u'ҿ', u'Ҿ'},      // 04bf → 04be
    {u'ӂ', u'Ӂ'},      // 04c2 → 04c1
    {u'ӄ', u'Ӄ'},      // 04c4 → 04c3
    {u'ӆ', u'Ӆ'},      // 04c6 → 04c5
    {u'ӈ', u'Ӈ'},      // 04c8 → 04c7
    {u'ӊ', u'Ӊ'},      // 04ca → 04c9
    {u'ӌ', u'Ӌ'},      // 04cc → 04cb
    {u'ӎ', u'Ӎ'},      // 04ce → 04cd
    {u'ӑ', u'Ӑ'},      // 04d1 → 04d0
    {u'ӓ', u'Ӓ'},      // 04d3 → 04d2
    {u'ӕ', u'Ӕ'},      // 04d5 → 04d4
    {u'ӗ', u'Ӗ'},      // 04d7 → 04d6
    {u'ә', u'Ә'},      // 04d9 → 04d8
    {u'ӛ', u'Ӛ'},      // 04db → 04da
    {u'ӝ', u'Ӝ'},      // 04dd → 04dc
    {u'ӟ', u'Ӟ'},      // 04df → 04de
    {u'ӡ', u'Ӡ'},      // 04e1 → 04e0
    {u'ӣ', u'Ӣ'},      // 04e3 → 04e2
    {u'ӥ', u'Ӥ'},      // 04e5 → 04e4
    {u'ӧ', u'Ӧ'},      // 04e7 → 04e6
    {u'ө', u'Ө'},      // 04e9 → 04e8
    {u'ӫ', u'Ӫ'},      // 04eb → 04ea
    {u'ӭ', u'Ӭ'},      // 04ed → 04ec
    {u'ӯ', u'Ӯ'},      // 04ef → 04ee
    {u'ӱ', u'Ӱ'},      // 04f1 → 04f0
    {u'ӳ', u'Ӳ'},      // 04f3 → 04f2
    {u'ӵ', u'Ӵ'},      // 04f5 → 04f4
    {u'ӷ', u'Ӷ'},      // 04f7 → 04f6
    {u'ӹ', u'Ӹ'},      // 04f9 → 04f8
    {u'ӻ', u'Ӻ'},      // 04fb → 04fa
    {u'ӽ', u'Ӽ'},      // 04fd → 04fc
    {u'ӿ', u'Ӿ'},      // 04ff → 04fe
    {u'ԁ', u'Ԁ'},      // 0501 → 0500
    {u'ԃ', u'Ԃ'},      // 0503 → 0502
    {u'ԅ', u'Ԅ'},      // 0505 → 0504
    {u'ԇ', u'Ԇ'},      // 0507 → 0506
    {u'ԉ', u'Ԉ'},      // 0509 → 0508
    {u'ԋ', u'Ԋ'},      // 050b → 050a
    {u'ԍ', u'Ԍ'},      // 050d → 050c
    {u'ԏ', u'Ԏ'},      // 050f → 050e
    {u'ԑ', u'Ԑ'},      // 0511 → 0510
    {u'ԓ', u'Ԓ'},      // 0513 → 0512
    {u'ԕ', u'Ԕ'},      // 0515 → 0514
    {u'ԗ', u'Ԗ'},      // 0517 → 0516
    {u'ԙ', u'Ԙ'},      // 0519 → 0518
    {u'ԛ', u'Ԛ'},      // 051b → 051a
    {u'ԝ', u'Ԝ'},      // 051d → 051c
    {u'ԟ', u'Ԟ'},      // 051f → 051e
    {u'ԡ', u'Ԡ'},      // 0521 → 0520
    {u'ԣ', u'Ԣ'},      // 0523 → 0522
    {u'ԥ', u'Ԥ'},      // 0525 → 0524
    {u'ԧ', u'Ԧ'},      // 0527 → 0526
    {u'ԩ', u'Ԩ'},    // 0529 → 0528
    {u'ԫ', u'Ԫ'},    // 052b → 052a
    {u'ԭ', u'Ԭ'},    // 052d → 052c
    {u'ԯ', u'Ԯ'},    // 052f → 052e
    {u'ա', u'Ա'},      // 0561 → 0531
    {u'բ', u'Բ'},      // 0562 → 0532
    {u'գ', u'Գ'},      // 0563 → 0533
    {u'դ', u'Դ'},      // 0564 → 0534
    {u'ե', u'Ե'},      // 0565 → 0535
    {u'զ', u'Զ'},      // 0566 → 0536
    {u'է', u'Է'},      // 0567 → 0537
    {u'ը', u'Ը'},      // 0568 → 0538
    {u'թ', u'Թ'},      // 0569 → 0539
    {u'ժ', u'Ժ'},      // 056a → 053a
    {u'ի', u'Ի'},      // 056b → 053b
    {u'լ', u'Լ'},      // 056c → 053c
    {u'խ', u'Խ'},      // 056d → 053d
    {u'ծ', u'Ծ'},      // 056e → 053e
    {u'կ', u'Կ'},      // 056f → 053f
    {u'հ', u'Հ'},      // 0570 → 0540
    {u'ձ', u'Ձ'},      // 0571 → 0541
    {u'ղ', u'Ղ'},      // 0572 → 0542
    {u'ճ', u'Ճ'},      // 0573 → 0543
    {u'մ', u'Մ'},      // 0574 → 0544
    {u'յ', u'Յ'},      // 0575 → 0545
    {u'ն', u'Ն'},      // 0576 → 0546
    {u'շ', u'Շ'},      // 0577 → 0547
    {u'ո', u'Ո'},      // 0578 → 0548
    {u'չ', u'Չ'},      // 0579 → 0549
    {u'պ', u'Պ'},      // 057a → 054a
    {u'ջ', u'Ջ'},      // 057b → 054b
    {u'ռ', u'Ռ'},      // 057c → 054c
    {u'ս', u'Ս'},      // 057d → 054d
    {u'վ', u'Վ'},      // 057e → 054e
    {u'տ', u'Տ'},      // 057f → 054f
    {u'ր', u'Ր'},      // 0580 → 0550
    {u'ց', u'Ց'},      // 0581 → 0551
    {u'ւ', u'Ւ'},      // 0582 → 0552
    {u'փ', u'Փ'},      // 0583 → 0553
    {u'ք', u'Ք'},      // 0584 → 0554
    {u'օ', u'Օ'},      // 0585 → 0555
    {u'ֆ', u'Ֆ'},      // 0586 → 0556
    {u'ᏸ', u'Ᏸ'},    // 13f8 → 13f0
    {u'ᏹ', u'Ᏹ'},    // 13f9 → 13f1
    {u'ᏺ', u'Ᏺ'},    // 13fa → 13f2
    {u'ᏻ', u'Ᏻ'},    // 13fb → 13f3
    {u'ᏼ', u'Ᏼ'},    // 13fc → 13f4
    {u'ᏽ', u'Ᏽ'},  // 13fd → 13f5
    {u'ᵹ', u'Ᵹ'},      // 1d79 → a77d
    {u'ᵽ', u'Ᵽ'},      // 1d7d → 2c63
    {u'ᶎ', u'Ᶎ'},    // 1d8e → a7c6
    {u'ḁ', u'Ḁ'},      // 1e01 → 1e00
    {u'ḃ', u'Ḃ'},      // 1e03 → 1e02
    {u'ḅ', u'Ḅ'},      // 1e05 → 1e04
    {u'ḇ', u'Ḇ'},      // 1e07 → 1e06
    {u'ḉ', u'Ḉ'},      // 1e09 → 1e08
    {u'ḋ', u'Ḋ'},      // 1e0b → 1e0a
    {u'ḍ', u'Ḍ'},      // 1e0d → 1e0c
    {u'ḏ', u'Ḏ'},      // 1e0f → 1e0e
    {u'ḑ', u'Ḑ'},      // 1e11 → 1e10
    {u'ḓ', u'Ḓ'},      // 1e13 → 1e12
    {u'ḕ', u'Ḕ'},      // 1e15 → 1e14
    {u'ḗ', u'Ḗ'},      // 1e17 → 1e16
    {u'ḙ', u'Ḙ'},      // 1e19 → 1e18
    {u'ḛ', u'Ḛ'},      // 1e1b → 1e1a
    {u'ḛ', u'Ẽ'},      // 1e1b → 1ebc
    {u'ḝ', u'Ḝ'},      // 1e1d → 1e1c
    {u'ḟ', u'Ḟ'},      // 1e1f → 1e1e
    {u'ḡ', u'Ḡ'},      // 1e21 → 1e20
    {u'ḣ', u'Ḣ'},      // 1e23 → 1e22
    {u'ḥ', u'Ḥ'},      // 1e25 → 1e24
    {u'ḧ', u'Ḧ'},      // 1e27 → 1e26
    {u'ḩ', u'Ḩ'},      // 1e29 → 1e28
    {u'ḫ', u'Ḫ'},      // 1e2b → 1e2a
    {u'ḭ', u'Ḭ'},      // 1e2d → 1e2c
    {u'ḯ', u'Ḯ'},      // 1e2f → 1e2e
    {u'ḱ', u'Ḱ'},      // 1e31 → 1e30
    {u'ḳ', u'Ḳ'},      // 1e33 → 1e32
    {u'ḵ', u'Ḵ'},      // 1e35 → 1e34
    {u'ḷ', u'Ḷ'},      // 1e37 → 1e36
    {u'ḹ', u'Ḹ'},      // 1e39 → 1e38
    {u'ḻ', u'Ḻ'},      // 1e3b → 1e3a
    {u'ḽ', u'Ḽ'},      // 1e3d → 1e3c
    {u'ḿ', u'Ḿ'},      // 1e3f → 1e3e
    {u'ṁ', u'Ṁ'},      // 1e41 → 1e40
    {u'ṃ', u'Ṃ'},      // 1e43 → 1e42
    {u'ṅ', u'Ṅ'},      // 1e45 → 1e44
    {u'ṇ', u'Ṇ'},      // 1e47 → 1e46
    {u'ṉ', u'Ṉ'},      // 1e49 → 1e48
    {u'ṋ', u'Ṋ'},      // 1e4b → 1e4a
    {u'ṍ', u'Ṍ'},      // 1e4d → 1e4c
    {u'ṏ', u'Ṏ'},      // 1e4f → 1e4e
    {u'ṑ', u'Ṑ'},      // 1e51 → 1e50
    {u'ṓ', u'Ṓ'},      // 1e53 → 1e52
    {u'ṕ', u'Ṕ'},      // 1e55 → 1e54
    {u'ṗ', u'Ṗ'},      // 1e57 → 1e56
    {u'ṙ', u'Ṙ'},      // 1e59 → 1e58
    {u'ṛ', u'Ṛ'},      // 1e5b → 1e5a
    {u'ṝ', u'Ṝ'},      // 1e5d → 1e5c
    {u'ṟ', u'Ṟ'},      // 1e5f → 1e5e
    {u'ṡ', u'Ṡ'},      // 1e61 → 1e60
    {u'ṣ', u'Ṣ'},      // 1e63 → 1e62
    {u'ṥ', u'Ṥ'},      // 1e65 → 1e64
    {u'ṧ', u'Ṧ'},      // 1e67 → 1e66
    {u'ṩ', u'Ṩ'},      // 1e69 → 1e68
    {u'ṫ', u'Ṫ'},      // 1e6b → 1e6a
    {u'ṭ', u'Ṭ'},      // 1e6d → 1e6c
    {u'ṯ', u'Ṯ'},      // 1e6f → 1e6e
    {u'ṱ', u'Ṱ'},      // 1e71 → 1e70
    {u'ṳ', u'Ṳ'},      // 1e73 → 1e72
    {u'ṵ', u'Ṵ'},      // 1e75 → 1e74
    {u'ṷ', u'Ṷ'},      // 1e77 → 1e76
    {u'ṹ', u'Ṹ'},      // 1e79 → 1e78
    {u'ṻ', u'Ṻ'},      // 1e7b → 1e7a
    {u'ṽ', u'Ṽ'},      // 1e7d → 1e7c
    {u'ṿ', u'Ṿ'},      // 1e7f → 1e7e
    {u'ẁ', u'Ẁ'},      // 1e81 → 1e80
    {u'ẃ', u'Ẃ'},      // 1e83 → 1e82
    {u'ẅ', u'Ẅ'},      // 1e85 → 1e84
    {u'ẇ', u'Ẇ'},      // 1e87 → 1e86
    {u'ẉ', u'Ẉ'},      // 1e89 → 1e88
    {u'ẋ', u'Ẋ'},      // 1e8b → 1e8a
    {u'ẍ', u'Ẍ'},      // 1e8d → 1e8c
    {u'ẏ', u'Ẏ'},      // 1e8f → 1e8e
    {u'ẑ', u'Ẑ'},      // 1e91 → 1e90
    {u'ẓ', u'Ẓ'},      // 1e93 → 1e92
    {u'ẕ', u'Ẕ'},      // 1e95 → 1e94
    {u'ạ', u'Ạ'},      // 1ea1 → 1ea0
    {u'ả', u'Ả'},      // 1ea3 → 1ea2
    {u'ấ', u'Ấ'},      // 1ea5 → 1ea4
    {u'ầ', u'Ầ'},      // 1ea7 → 1ea6
    {u'ẩ', u'Ẩ'},      // 1ea9 → 1ea8
    {u'ẫ', u'Ẫ'},      // 1eab → 1eaa
    {u'ậ', u'Ậ'},      // 1ead → 1eac
    {u'ắ', u'Ắ'},      // 1eaf → 1eae
    {u'ằ', u'Ằ'},      // 1eb1 → 1eb0
    {u'ẳ', u'Ẳ'},      // 1eb3 → 1eb2
    {u'ẵ', u'Ẵ'},      // 1eb5 → 1eb4
    {u'ặ', u'Ặ'},      // 1eb7 → 1eb6
    {u'ẹ', u'Ẹ'},      // 1eb9 → 1eb8
    {u'ẻ', u'Ẻ'},      // 1ebb → 1eba
    {u'ế', u'Ế'},      // 1ebf → 1ebe
    {u'ề', u'Ề'},      // 1ec1 → 1ec0
    {u'ể', u'Ể'},      // 1ec3 → 1ec2
    {u'ễ', u'Ễ'},      // 1ec5 → 1ec4
    {u'ệ', u'Ệ'},      // 1ec7 → 1ec6
    {u'ỉ', u'Ỉ'},      // 1ec9 → 1ec8
    {u'ị', u'Ị'},      // 1ecb → 1eca
    {u'ọ', u'Ọ'},      // 1ecd → 1ecc
    {u'ỏ', u'Ỏ'},      // 1ecf → 1ece
    {u'ố', u'Ố'},      // 1ed1 → 1ed0
    {u'ồ', u'Ồ'},      // 1ed3 → 1ed2
    {u'ổ', u'Ổ'},      // 1ed5 → 1ed4
    {u'ỗ', u'Ỗ'},      // 1ed7 → 1ed6
    {u'ộ', u'Ộ'},      // 1ed9 → 1ed8
    {u'ớ', u'Ớ'},      // 1edb → 1eda
    {u'ờ', u'Ờ'},      // 1edd → 1edc
    {u'ở', u'Ở'},      // 1edf → 1ede
    {u'ỡ', u'Ỡ'},      // 1ee1 → 1ee0
    {u'ợ', u'Ợ'},      // 1ee3 → 1ee2
    {u'ụ', u'Ụ'},      // 1ee5 → 1ee4
    {u'ủ', u'Ủ'},      // 1ee7 → 1ee6
    {u'ứ', u'Ứ'},      // 1ee9 → 1ee8
    {u'ừ', u'Ừ'},      // 1eeb → 1eea
    {u'ử', u'Ử'},      // 1eed → 1eec
    {u'ữ', u'Ữ'},      // 1eef → 1eee
    {u'ự', u'Ự'},      // 1ef1 → 1ef0
    {u'ỳ', u'Ỳ'},      // 1ef3 → 1ef2
    {u'ỵ', u'Ỵ'},      // 1ef5 → 1ef4
    {u'ỷ', u'Ỷ'},      // 1ef7 → 1ef6
    {u'ỹ', u'Ỹ'},      // 1ef9 → 1ef8
    {u'ỻ', u'Ỻ'},      // 1efb → 1efa
    {u'ỽ', u'Ỽ'},      // 1efd → 1efc
    {u'ỿ', u'Ỿ'},      // 1eff → 1efe
    {u'ἀ', u'Ἀ'},      // 1f00 → 1f08
    {u'ἁ', u'Ἁ'},      // 1f01 → 1f09
    {u'ἂ', u'Ἂ'},      // 1f02 → 1f0a
    {u'ἃ', u'Ἃ'},      // 1f03 → 1f0b
    {u'ἄ', u'Ἄ'},      // 1f04 → 1f0c
    {u'ἅ', u'Ἅ'},      // 1f05 → 1f0d
    {u'ἆ', u'Ἆ'},      // 1f06 → 1f0e
    {u'ἇ', u'Ἇ'},      // 1f07 → 1f0f
    {u'ἐ', u'Ἐ'},      // 1f10 → 1f18
    {u'ἑ', u'Ἑ'},      // 1f11 → 1f19
    {u'ἒ', u'Ἒ'},      // 1f12 → 1f1a
    {u'ἓ', u'Ἓ'},      // 1f13 → 1f1b
    {u'ἔ', u'Ἔ'},      // 1f14 → 1f1c
    {u'ἕ', u'Ἕ'},      // 1f15 → 1f1d
    {u'ἠ', u'Ἠ'},      // 1f20 → 1f28
    {u'ἡ', u'Ἡ'},      // 1f21 → 1f29
    {u'ἢ', u'Ἢ'},      // 1f22 → 1f2a
    {u'ἣ', u'Ἣ'},      // 1f23 → 1f2b
    {u'ἤ', u'Ἤ'},      // 1f24 → 1f2c
    {u'ἥ', u'Ἥ'},      // 1f25 → 1f2d
    {u'ἦ', u'Ἦ'},      // 1f26 → 1f2e
    {u'ἧ', u'Ἧ'},      // 1f27 → 1f2f
    {u'ἰ', u'Ἰ'},      // 1f30 → 1f38
    {u'ἱ', u'Ἱ'},      // 1f31 → 1f39
    {u'ἲ', u'Ἲ'},      // 1f32 → 1f3a
    {u'ἳ', u'Ἳ'},      // 1f33 → 1f3b
    {u'ἴ', u'Ἴ'},      // 1f34 → 1f3c
    {u'ἵ', u'Ἵ'},      // 1f35 → 1f3d
    {u'ἶ', u'Ἶ'},      // 1f36 → 1f3e
    {u'ἷ', u'Ἷ'},      // 1f37 → 1f3f
    {u'ὀ', u'Ὀ'},      // 1f40 → 1f48
    {u'ὁ', u'Ὁ'},      // 1f41 → 1f49
    {u'ὂ', u'Ὂ'},      // 1f42 → 1f4a
    {u'ὃ', u'Ὃ'},      // 1f43 → 1f4b
    {u'ὄ', u'Ὄ'},      // 1f44 → 1f4c
    {u'ὅ', u'Ὅ'},      // 1f45 → 1f4d
    {u'ὑ', u'Ὑ'},      // 1f51 → 1f59
    {u'ὓ', u'Ὓ'},      // 1f53 → 1f5b
    {u'ὕ', u'Ὕ'},      // 1f55 → 1f5d
    {u'ὗ', u'Ὗ'},      // 1f57 → 1f5f
    {u'ὠ', u'Ὠ'},      // 1f60 → 1f68
    {u'ὡ', u'Ὡ'},      // 1f61 → 1f69
    {u'ὢ', u'Ὢ'},      // 1f62 → 1f6a
    {u'ὣ', u'Ὣ'},      // 1f63 → 1f6b
    {u'ὤ', u'Ὤ'},      // 1f64 → 1f6c
    {u'ὥ', u'Ὥ'},      // 1f65 → 1f6d
    {u'ὦ', u'Ὦ'},      // 1f66 → 1f6e
    {u'ὧ', u'Ὧ'},      // 1f67 → 1f6f
    {u'ὰ', u'Ὰ'},      // 1f70 → 1fba
    {u'ά', u'Ά'},      // 1f71 → 1fbb
    {u'ὲ', u'Ὲ'},      // 1f72 → 1fc8
    {u'έ', u'Έ'},      // 1f73 → 1fc9
    {u'ὴ', u'Ὴ'},      // 1f74 → 1fca
    {u'ή', u'Ή'},      // 1f75 → 1fcb
    {u'ὶ', u'Ὶ'},      // 1f76 → 1fda
    {u'ί', u'Ί'},      // 1f77 → 1fdb
    {u'ὸ', u'Ὸ'},      // 1f78 → 1ff8
    {u'ό', u'Ό'},      // 1f79 → 1ff9
    {u'ὺ', u'Ὺ'},      // 1f7a → 1fea
    {u'ύ', u'Ύ'},      // 1f7b → 1feb
    {u'ὼ', u'Ὼ'},      // 1f7c → 1ffa
    {u'ώ', u'Ώ'},      // 1f7d → 1ffb
    {u'ᾰ', u'Ᾰ'},      // 1fb0 → 1fb8
    {u'ᾱ', u'Ᾱ'},      // 1fb1 → 1fb9
    {u'ῐ', u'Ῐ'},      // 1fd0 → 1fd8
    {u'ῑ', u'Ῑ'},      // 1fd1 → 1fd9
    {u'ῠ', u'Ῠ'},      // 1fe0 → 1fe8
    {u'ῡ', u'Ῡ'},      // 1fe1 → 1fe9
    {u'ῥ', u'Ῥ'},      // 1fe5 → 1fec
    {u'ℓ', u'ℒ'},      // 2113 → 2112
    {u'ℯ', u'ℰ'},      // 212f → 2130
    {u'ℼ', u'ℿ'},      // 213c → 213f
    {u'ℼ', u'ℙ'},      // 213c → 2119
    {u'ℽ', u'ℾ'},      // 213d → 213e
    {u'ⅆ', u'ⅅ'},      // 2146 → 2145
    {u'ⅎ', u'Ⅎ'},      // 214e → 2132
    {u'ⰰ', u'Ⰰ'},      // 2c30 → 2c00
    {u'ⰱ', u'Ⰱ'},      // 2c31 → 2c01
    {u'ⰲ', u'Ⰲ'},      // 2c32 → 2c02
    {u'ⰳ', u'Ⰳ'},      // 2c33 → 2c03
    {u'ⰴ', u'Ⰴ'},      // 2c34 → 2c04
    {u'ⰵ', u'Ⰵ'},      // 2c35 → 2c05
    {u'ⰶ', u'Ⰶ'},      // 2c36 → 2c06
    {u'ⰷ', u'Ⰷ'},      // 2c37 → 2c07
    {u'ⰸ', u'Ⰸ'},      // 2c38 → 2c08
    {u'ⰹ', u'Ⰹ'},      // 2c39 → 2c09
    {u'ⰹ', u'Ⰻ'},      // 2c39 → 2c0b
    {u'ⰺ', u'Ⰺ'},      // 2c3a → 2c0a
    {u'ⰼ', u'Ⰼ'},      // 2c3c → 2c0c
    {u'ⰽ', u'Ⰽ'},      // 2c3d → 2c0d
    {u'ⰾ', u'Ⰾ'},      // 2c3e → 2c0e
    {u'ⰿ', u'Ⰿ'},      // 2c3f → 2c0f
    {u'ⱀ', u'Ⱀ'},      // 2c40 → 2c10
    {u'ⱁ', u'Ⱁ'},      // 2c41 → 2c11
    {u'ⱂ', u'Ⱂ'},      // 2c42 → 2c12
    {u'ⱃ', u'Ⱃ'},      // 2c43 → 2c13
    {u'ⱄ', u'Ⱄ'},      // 2c44 → 2c14
    {u'ⱅ', u'Ⱅ'},      // 2c45 → 2c15
    {u'ⱆ', u'Ⱆ'},      // 2c46 → 2c16
    {u'ⱇ', u'Ⱇ'},      // 2c47 → 2c17
    {u'ⱈ', u'Ⱈ'},      // 2c48 → 2c18
    {u'ⱉ', u'Ⱉ'},      // 2c49 → 2c19
    {u'ⱊ', u'Ⱊ'},      // 2c4a → 2c1a
    {u'ⱋ', u'Ⱋ'},      // 2c4b → 2c1b
    {u'ⱌ', u'Ⱌ'},      // 2c4c → 2c1c
    {u'ⱍ', u'Ⱍ'},      // 2c4d → 2c1d
    {u'ⱎ', u'Ⱎ'},      // 2c4e → 2c1e
    {u'ⱏ', u'Ⱏ'},      // 2c4f → 2c1f
    {u'ⱐ', u'Ⱐ'},      // 2c50 → 2c20
    {u'ⱑ', u'Ⱑ'},      // 2c51 → 2c21
    {u'ⱒ', u'Ⱒ'},      // 2c52 → 2c22
    {u'ⱓ', u'Ⱓ'},      // 2c53 → 2c23
    {u'ⱔ', u'Ⱔ'},      // 2c54 → 2c24
    {u'ⱕ', u'Ⱕ'},      // 2c55 → 2c25
    {u'ⱖ', u'Ⱖ'},      // 2c56 → 2c26
    {u'ⱗ', u'Ⱗ'},      // 2c57 → 2c27
    {u'ⱘ', u'Ⱘ'},      // 2c58 → 2c28
    {u'ⱙ', u'Ⱙ'},      // 2c59 → 2c29
    {u'ⱚ', u'Ⱚ'},      // 2c5a → 2c2a
    {u'ⱛ', u'Ⱛ'},      // 2c5b → 2c2b
    {u'ⱜ', u'Ⱜ'},      // 2c5c → 2c2c
    {u'ⱝ', u'Ⱝ'},      // 2c5d → 2c2d
    {u'ⱞ', u'Ⱞ'},      // 2c5e → 2c2e
    {u'ⱡ', u'Ⱡ'},      // 2c61 → 2c60
    {u'ⱥ', u'Ⱥ'},      // 2c65 → 023a
    {u'ⱦ', u'Ⱦ'},      // 2c66 → 023e
    {u'ⱨ', u'Ⱨ'},      // 2c68 → 2c67
    {u'ⱪ', u'Ⱪ'},      // 2c6a → 2c69
    {u'ⱬ', u'Ⱬ'},      // 2c6c → 2c6b
    {u'ⱳ', u'Ⱳ'},      // 2c73 → 2c72
    {u'ⱶ', u'Ⱶ'},      // 2c76 → 2c75
    {u'ⲁ', u'Ⲁ'},      // 2c81 → 2c80
    {u'ⲃ', u'Ⲃ'},      // 2c83 → 2c82
    {u'ⲅ', u'Ⲅ'},      // 2c85 → 2c84
    {u'ⲇ', u'Ⲇ'},      // 2c87 → 2c86
    {u'ⲉ', u'Ⲉ'},      // 2c89 → 2c88
    {u'ⲋ', u'Ⲋ'},      // 2c8b → 2c8a
    {u'ⲍ', u'Ⲍ'},      // 2c8d → 2c8c
    {u'ⲏ', u'Ⲏ'},      // 2c8f → 2c8e
    {u'ⲑ', u'Ⲑ'},      // 2c91 → 2c90
    {u'ⲓ', u'Ⲓ'},      // 2c93 → 2c92
    {u'ⲕ', u'Ⲕ'},      // 2c95 → 2c94
    {u'ⲗ', u'Ⲗ'},      // 2c97 → 2c96
    {u'ⲙ', u'Ⲙ'},      // 2c99 → 2c98
    {u'ⲛ', u'Ⲛ'},      // 2c9b → 2c9a
    {u'ⲝ', u'Ⲝ'},      // 2c9d → 2c9c
    {u'ⲟ', u'Ⲟ'},      // 2c9f → 2c9e
    {u'ⲡ', u'Ⲡ'},      // 2ca1 → 2ca0
    {u'ⲣ', u'Ⲣ'},      // 2ca3 → 2ca2
    {u'ⲥ', u'Ⲥ'},      // 2ca5 → 2ca4
    {u'ⲧ', u'Ⲧ'},      // 2ca7 → 2ca6
    {u'ⲩ', u'Ⲩ'},      // 2ca9 → 2ca8
    {u'ⲫ', u'Ⲫ'},      // 2cab → 2caa
    {u'ⲭ', u'Ⲭ'},      // 2cad → 2cac
    {u'ⲯ', u'Ⲯ'},      // 2caf → 2cae
    {u'ⲱ', u'Ⲱ'},      // 2cb1 → 2cb0
    {u'ⲳ', u'Ⲳ'},      // 2cb3 → 2cb2
    {u'ⲵ', u'Ⲵ'},      // 2cb5 → 2cb4
    {u'ⲷ', u'Ⲷ'},      // 2cb7 → 2cb6
    {u'ⲹ', u'Ⲹ'},      // 2cb9 → 2cb8
    {u'ⲻ', u'Ⲻ'},      // 2cbb → 2cba
    {u'ⲽ', u'Ⲽ'},      // 2cbd → 2cbc
    {u'ⲿ', u'Ⲿ'},      // 2cbf → 2cbe
    {u'ⳁ', u'Ⳁ'},      // 2cc1 → 2cc0
    {u'ⳃ', u'Ⳃ'},      // 2cc3 → 2cc2
    {u'ⳅ', u'Ⳅ'},      // 2cc5 → 2cc4
    {u'ⳇ', u'Ⳇ'},      // 2cc7 → 2cc6
    {u'ⳉ', u'Ⳉ'},      // 2cc9 → 2cc8
    {u'ⳋ', u'Ⳋ'},      // 2ccb → 2cca
    {u'ⳍ', u'Ⳍ'},      // 2ccd → 2ccc
    {u'ⳏ', u'Ⳏ'},      // 2ccf → 2cce
    {u'ⳑ', u'Ⳑ'},      // 2cd1 → 2cd0
    {u'ⳓ', u'Ⳓ'},      // 2cd3 → 2cd2
    {u'ⳕ', u'Ⳕ'},      // 2cd5 → 2cd4
    {u'ⳗ', u'Ⳗ'},      // 2cd7 → 2cd6
    {u'ⳙ', u'Ⳙ'},      // 2cd9 → 2cd8
    {u'ⳛ', u'Ⳛ'},      // 2cdb → 2cda
    {u'ⳝ', u'Ⳝ'},      // 2cdd → 2cdc
    {u'ⳟ', u'Ⳟ'},      // 2cdf → 2cde
    {u'ⳡ', u'Ⳡ'},      // 2ce1 → 2ce0
    {u'ⳣ', u'Ⳣ'},      // 2ce3 → 2ce2
    {u'ⳬ', u'Ⳬ'},      // 2cec → 2ceb
    {u'ⳮ', u'Ⳮ'},      // 2cee → 2ced
    {u'ⳳ', u'Ⳳ'},      // 2cf3 → 2cf2
    {u'ⴀ', u'Ⴀ'},      // 2d00 → 10a0
    {u'ⴁ', u'Ⴁ'},      // 2d01 → 10a1
    {u'ⴂ', u'Ⴂ'},      // 2d02 → 10a2
    {u'ⴃ', u'Ⴃ'},      // 2d03 → 10a3
    {u'ⴄ', u'Ⴄ'},      // 2d04 → 10a4
    {u'ⴅ', u'Ⴅ'},      // 2d05 → 10a5
    {u'ⴆ', u'Ⴆ'},      // 2d06 → 10a6
    {u'ⴇ', u'Ⴇ'},      // 2d07 → 10a7
    {u'ⴈ', u'Ⴈ'},      // 2d08 → 10a8
    {u'ⴉ', u'Ⴉ'},      // 2d09 → 10a9
    {u'ⴊ', u'Ⴊ'},      // 2d0a → 10aa
    {u'ⴋ', u'Ⴋ'},      // 2d0b → 10ab
    {u'ⴌ', u'Ⴌ'},      // 2d0c → 10ac
    {u'ⴍ', u'Ⴍ'},      // 2d0d → 10ad
    {u'ⴎ', u'Ⴎ'},      // 2d0e → 10ae
    {u'ⴏ', u'Ⴏ'},      // 2d0f → 10af
    {u'ⴐ', u'Ⴐ'},      // 2d10 → 10b0
    {u'ⴑ', u'Ⴑ'},      // 2d11 → 10b1
    {u'ⴒ', u'Ⴒ'},      // 2d12 → 10b2
    {u'ⴓ', u'Ⴓ'},      // 2d13 → 10b3
    {u'ⴔ', u'Ⴔ'},      // 2d14 → 10b4
    {u'ⴕ', u'Ⴕ'},      // 2d15 → 10b5
    {u'ⴖ', u'Ⴖ'},      // 2d16 → 10b6
    {u'ⴗ', u'Ⴗ'},      // 2d17 → 10b7
    {u'ⴘ', u'Ⴘ'},      // 2d18 → 10b8
    {u'ⴙ', u'Ⴙ'},      // 2d19 → 10b9
    {u'ⴚ', u'Ⴚ'},      // 2d1a → 10ba
    {u'ⴛ', u'Ⴛ'},      // 2d1b → 10bb
    {u'ⴜ', u'Ⴜ'},      // 2d1c → 10bc
    {u'ⴝ', u'Ⴝ'},      // 2d1d → 10bd
    {u'ⴞ', u'Ⴞ'},      // 2d1e → 10be
    {u'ⴟ', u'Ⴟ'},      // 2d1f → 10bf
    {u'ⴠ', u'Ⴠ'},      // 2d20 → 10c0
    {u'ⴡ', u'Ⴡ'},      // 2d21 → 10c1
    {u'ⴢ', u'Ⴢ'},      // 2d22 → 10c2
    {u'ⴣ', u'Ⴣ'},      // 2d23 → 10c3
    {u'ⴤ', u'Ⴤ'},      // 2d24 → 10c4
    {u'ⴥ', u'Ⴥ'},      // 2d25 → 10c5
    {u'ⴧ', u'Ⴧ'},      // 2d27 → 10c7
    {u'ⴭ', u'Ⴭ'},      // 2d2d → 10cd
    {u'ꙁ', u'Ꙁ'},      // a641 → a640
    {u'ꙃ', u'Ꙃ'},      // a643 → a642
    {u'ꙅ', u'Ꙅ'},      // a645 → a644
    {u'ꙇ', u'Ꙇ'},      // a647 → a646
    {u'ꙉ', u'Ꙉ'},      // a649 → a648
    {u'ꙋ', u'Ꙋ'},      // a64b → a64a
    {u'ꙍ', u'Ꙍ'},      // a64d → a64c
    {u'ꙏ', u'Ꙏ'},      // a64f → a64e
    {u'ꙑ', u'Ꙑ'},      // a651 → a650
    {u'ꙓ', u'Ꙓ'},      // a653 → a652
    {u'ꙕ', u'Ꙕ'},      // a655 → a654
    {u'ꙗ', u'Ꙗ'},      // a657 → a656
    {u'ꙙ', u'Ꙙ'},      // a659 → a658
    {u'ꙛ', u'Ꙛ'},      // a65b → a65a
    {u'ꙝ', u'Ꙝ'},      // a65d → a65c
    {u'ꙟ', u'Ꙟ'},      // a65f → a65e
    {u'ꙡ', u'Ꙡ'},      // a661 → a660
    {u'ꙣ', u'Ꙣ'},      // a663 → a662
    {u'ꙥ', u'Ꙥ'},      // a665 → a664
    {u'ꙧ', u'Ꙧ'},      // a667 → a666
    {u'ꙩ', u'Ꙩ'},      // a669 → a668
    {u'ꙫ', u'Ꙫ'},      // a66b → a66a
    {u'ꙭ', u'Ꙭ'},      // a66d → a66c
    {u'ꚁ', u'Ꚁ'},      // a681 → a680
    {u'ꚃ', u'Ꚃ'},      // a683 → a682
    {u'ꚅ', u'Ꚅ'},      // a685 → a684
    {u'ꚇ', u'Ꚇ'},      // a687 → a686
    {u'ꚉ', u'Ꚉ'},      // a689 → a688
    {u'ꚋ', u'Ꚋ'},      // a68b → a68a
    {u'ꚍ', u'Ꚍ'},      // a68d → a68c
    {u'ꚏ', u'Ꚏ'},      // a68f → a68e
    {u'ꚑ', u'Ꚑ'},      // a691 → a690
    {u'ꚓ', u'Ꚓ'},      // a693 → a692
    {u'ꚕ', u'Ꚕ'},      // a695 → a694
    {u'ꚗ', u'Ꚗ'},      // a697 → a696
    {u'ꚙ', u'Ꚙ'},  // a699 → a698
    {u'ꚛ', u'Ꚛ'},  // a69b → a69a
    {u'ꜣ', u'Ꜣ'},      // a723 → a722
    {u'ꜥ', u'Ꜥ'},      // a725 → a724
    {u'ꜧ', u'Ꜧ'},      // a727 → a726
    {u'ꜩ', u'Ꜩ'},      // a729 → a728
    {u'ꜫ', u'Ꜫ'},      // a72b → a72a
    {u'ꜭ', u'Ꜭ'},      // a72d → a72c
    {u'ꜯ', u'Ꜯ'},      // a72f → a72e
    {u'ꜳ', u'Ꜳ'},      // a733 → a732
    {u'ꜵ', u'Ꜵ'},      // a735 → a734
    {u'ꜷ', u'Ꜷ'},      // a737 → a736
    {u'ꜹ', u'Ꜹ'},      // a739 → a738
    {u'ꜻ', u'Ꜻ'},      // a73b → a73a
    {u'ꜽ', u'Ꜽ'},      // a73d → a73c
    {u'ꜿ', u'Ꜿ'},      // a73f → a73e
    {u'ꝁ', u'Ꝁ'},      // a741 → a740
    {u'ꝃ', u'Ꝃ'},      // a743 → a742
    {u'ꝅ', u'Ꝅ'},      // a745 → a744
    {u'ꝇ', u'Ꝇ'},      // a747 → a746
    {u'ꝉ', u'Ꝉ'},      // a749 → a748
    {u'ꝋ', u'Ꝋ'},      // a74b → a74a
    {u'ꝍ', u'Ꝍ'},      // a74d → a74c
    {u'ꝏ', u'Ꝏ'},      // a74f → a74e
    {u'ꝑ', u'Ꝑ'},      // a751 → a750
    {u'ꝑ', u'Ꝧ'},      // a751 → a766
    {u'ꝑ', u'Ꝗ'},      // a751 → a756
    {u'ꝓ', u'Ꝓ'},      // a753 → a752
    {u'ꝕ', u'Ꝕ'},      // a755 → a754
    {u'ꝙ', u'Ꝙ'},      // a759 → a758
    {u'ꝛ', u'Ꝛ'},      // a75b → a75a
    {u'ꝝ', u'Ꝝ'},      // a75d → a75c
    {u'ꝟ', u'Ꝟ'},      // a75f → a75e
    {u'ꝡ', u'Ꝡ'},      // a761 → a760
    {u'ꝣ', u'Ꝣ'},      // a763 → a762
    {u'ꝥ', u'Ꝥ'},      // a765 → a764
    {u'ꝩ', u'Ꝩ'},      // a769 → a768
    {u'ꝫ', u'Ꝫ'},      // a76b → a76a
    {u'ꝭ', u'Ꝭ'},      // a76d → a76c
    {u'ꝯ', u'Ꝯ'},      // a76f → a76e
    {u'ꝺ', u'Ꝺ'},      // a77a → a779
    {u'ꝼ', u'Ꝼ'},      // a77c → a77b
    {u'ꝿ', u'Ꝿ'},      // a77f → a77e
    {u'ꞁ', u'Ꞁ'},      // a781 → a780
    {u'ꞃ', u'Ꞃ'},      // a783 → a782
    {u'ꞅ', u'Ꞅ'},      // a785 → a784
    {u'ꞇ', u'Ꞇ'},      // a787 → a786
    {u'ꞌ', u'Ꞌ'},      // a78c → a78b
    {u'ꞑ', u'Ꞑ'},      // a791 → a790
    {u'ꞓ', u'Ꞓ'},      // a793 → a792
    {u'ꞔ', u'Ꞔ'},  // a794 → a7c4
    {u'ꞗ', u'Ꞗ'},  // a797 → a796
    {u'ꞙ', u'Ꞙ'},  // a799 → a798
    {u'ꞛ', u'Ꞛ'},  // a79b → a79a
    {u'ꞝ', u'Ꞝ'},  // a79d → a79c
    {u'ꞟ', u'Ꞟ'},  // a79f → a79e
    {u'ꞡ', u'Ꞡ'},      // a7a1 → a7a0
    {u'ꞣ', u'Ꞣ'},      // a7a3 → a7a2
    {u'ꞥ', u'Ꞥ'},      // a7a5 → a7a4
    {u'ꞧ', u'Ꞧ'},      // a7a7 → a7a6
    {u'ꞩ', u'Ꞩ'},      // a7a9 → a7a8
    {u'ꞵ', u'Ꞵ'},  // a7b5 → a7b4
    {u'ꞷ', u'Ꞷ'},  // a7b7 → a7b6
    {u'ꞹ', u'Ꞹ'},  // a7b9 → a7b8
    {u'ꞻ', u'Ꞻ'},  // a7bb → a7ba
    {u'ꞽ', u'Ꞽ'},  // a7bd → a7bc
    {u'ꞿ', u'Ꞿ'},  // a7bf → a7be
    {u'ꟃ', u'Ꟃ'},  // a7c3 → a7c2
    {u'ꭓ', u'Ꭓ'},  // ab53 → a7b3
    {u'ａ', u'Ａ'},    // ff41 → ff21
    {u'ｂ', u'Ｂ'},    // ff42 → ff22
    {u'ｃ', u'Ｃ'},    // ff43 → ff23
    {u'ｄ', u'Ｄ'},    // ff44 → ff24
    {u'ｅ', u'Ｅ'},    // ff45 → ff25
    {u'ｆ', u'Ｆ'},    // ff46 → ff26
    {u'ｇ', u'Ｇ'},    // ff47 → ff27
    {u'ｈ', u'Ｈ'},    // ff48 → ff28
    {u'ｉ', u'Ｉ'},    // ff49 → ff29
    {u'ｊ', u'Ｊ'},    // ff4a → ff2a
    {u'ｋ', u'Ｋ'},    // ff4b → ff2b
    {u'ｌ', u'Ｌ'},    // ff4c → ff2c
    {u'ｍ', u'Ｍ'},    // ff4d → ff2d
    {u'ｎ', u'Ｎ'},    // ff4e → ff2e
    {u'ｏ', u'Ｏ'},    // ff4f → ff2f
    {u'ｐ', u'Ｐ'},    // ff50 → ff30
    {u'ｑ', u'Ｑ'},    // ff51 → ff31
    {u'ｒ', u'Ｒ'},    // ff52 → ff32
    {u'ｓ', u'Ｓ'},    // ff53 → ff33
    {u'ｔ', u'Ｔ'},    // ff54 → ff34
    {u'ｕ', u'Ｕ'},    // ff55 → ff35
    {u'ｖ', u'Ｖ'},    // ff56 → ff36
    {u'ｗ', u'Ｗ'},    // ff57 → ff37
    {u'ｘ', u'Ｘ'},    // ff58 → ff38
    {u'ｙ', u'Ｙ'},    // ff59 → ff39
    {u'ｚ', u'Ｚ'},    // ff5a → ff3a
#endif
};

static const char32_t kLowerToUpperAstral[][2] = {
    {L'𐐨', L'𐐀'},        // 00010428 → 00010400
    {L'𐐩', L'𐐁'},        // 00010429 → 00010401
    {L'𐐪', L'𐐂'},        // 0001042a → 00010402
    {L'𐐫', L'𐐃'},        // 0001042b → 00010403
    {L'𐐬', L'𐐄'},        // 0001042c → 00010404
    {L'𐐭', L'𐐅'},        // 0001042d → 00010405
    {L'𐐮', L'𐐆'},        // 0001042e → 00010406
    {L'𐐯', L'𐐇'},        // 0001042f → 00010407
    {L'𐐰', L'𐐈'},        // 00010430 → 00010408
    {L'𐐱', L'𐐉'},        // 00010431 → 00010409
    {L'𐐲', L'𐐊'},        // 00010432 → 0001040a
    {L'𐐳', L'𐐋'},        // 00010433 → 0001040b
    {L'𐐴', L'𐐌'},        // 00010434 → 0001040c
    {L'𐐵', L'𐐍'},        // 00010435 → 0001040d
    {L'𐐶', L'𐐎'},        // 00010436 → 0001040e
    {L'𐐷', L'𐐏'},        // 00010437 → 0001040f
    {L'𐐸', L'𐐐'},        // 00010438 → 00010410
    {L'𐐹', L'𐐑'},        // 00010439 → 00010411
    {L'𐐺', L'𐐒'},        // 0001043a → 00010412
    {L'𐐻', L'𐐓'},        // 0001043b → 00010413
    {L'𐐼', L'𐐔'},        // 0001043c → 00010414
    {L'𐐽', L'𐐕'},        // 0001043d → 00010415
    {L'𐐾', L'𐐖'},        // 0001043e → 00010416
    {L'𐐿', L'𐐗'},        // 0001043f → 00010417
    {L'𐑀', L'𐐘'},        // 00010440 → 00010418
    {L'𐑁', L'𐐙'},        // 00010441 → 00010419
    {L'𐑂', L'𐐚'},        // 00010442 → 0001041a
    {L'𐑃', L'𐐛'},        // 00010443 → 0001041b
    {L'𐑄', L'𐐜'},        // 00010444 → 0001041c
    {L'𐑅', L'𐐝'},        // 00010445 → 0001041d
    {L'𐑆', L'𐐞'},        // 00010446 → 0001041e
    {L'𐑇', L'𐐟'},        // 00010447 → 0001041f
    {L'𐑈', L'𐐠'},        // 00010448 → 00010420
    {L'𐑉', L'𐐡'},        // 00010449 → 00010421
    {L'𐑊', L'𐐢'},        // 0001044a → 00010422
    {L'𐑋', L'𐐣'},        // 0001044b → 00010423
    {L'𐑌', L'𐐤'},        // 0001044c → 00010424
    {L'𐑍', L'𐐥'},        // 0001044d → 00010425
    {L'𐑎', L'𐐦'},        // 0001044e → 00010426
    {L'𐑏', L'𐐧'},        // 0001044f → 00010427
    {L'𐓘', L'𐒰'},  // 000104d8 → 000104b0
    {L'𐓙', L'𐒱'},  // 000104d9 → 000104b1
    {L'𐓚', L'𐒲'},  // 000104da → 000104b2
    {L'𐓛', L'𐒳'},  // 000104db → 000104b3
    {L'𐓜', L'𐒴'},  // 000104dc → 000104b4
    {L'𐓝', L'𐒵'},  // 000104dd → 000104b5
    {L'𐓞', L'𐒶'},  // 000104de → 000104b6
    {L'𐓟', L'𐒷'},  // 000104df → 000104b7
    {L'𐓠', L'𐒸'},  // 000104e0 → 000104b8
    {L'𐓡', L'𐒹'},  // 000104e1 → 000104b9
    {L'𐓢', L'𐒺'},  // 000104e2 → 000104ba
    {L'𐓣', L'𐒻'},  // 000104e3 → 000104bb
    {L'𐓤', L'𐒼'},  // 000104e4 → 000104bc
    {L'𐓥', L'𐒽'},  // 000104e5 → 000104bd
    {L'𐓦', L'𐒾'},  // 000104e6 → 000104be
    {L'𐓧', L'𐒿'},  // 000104e7 → 000104bf
    {L'𐓨', L'𐓀'},  // 000104e8 → 000104c0
    {L'𐓩', L'𐓁'},  // 000104e9 → 000104c1
    {L'𐓪', L'𐓂'},  // 000104ea → 000104c2
    {L'𐓫', L'𐓃'},  // 000104eb → 000104c3
    {L'𐓬', L'𐓄'},  // 000104ec → 000104c4
    {L'𐓭', L'𐓅'},  // 000104ed → 000104c5
    {L'𐓮', L'𐓆'},  // 000104ee → 000104c6
    {L'𐓯', L'𐓇'},  // 000104ef → 000104c7
    {L'𐓰', L'𐓈'},  // 000104f0 → 000104c8
    {L'𐓱', L'𐓉'},  // 000104f1 → 000104c9
    {L'𐓲', L'𐓊'},  // 000104f2 → 000104ca
    {L'𐓳', L'𐓋'},  // 000104f3 → 000104cb
    {L'𐓴', L'𐓌'},  // 000104f4 → 000104cc
    {L'𐓵', L'𐓍'},  // 000104f5 → 000104cd
    {L'𐓶', L'𐓎'},  // 000104f6 → 000104ce
    {L'𐓷', L'𐓏'},  // 000104f7 → 000104cf
    {L'𐓸', L'𐓐'},  // 000104f8 → 000104d0
    {L'𐓹', L'𐓑'},  // 000104f9 → 000104d1
    {L'𐓺', L'𐓒'},  // 000104fa → 000104d2
    {L'𐓻', L'𐓓'},  // 000104fb → 000104d3
    {L'𐳀', L'𐲀'},  // 00010cc0 → 00010c80
    {L'𐳁', L'𐲁'},  // 00010cc1 → 00010c81
    {L'𐳂', L'𐲉'},  // 00010cc2 → 00010c89
    {L'𐳂', L'𐲂'},  // 00010cc2 → 00010c82
    {L'𐳃', L'𐲃'},  // 00010cc3 → 00010c83
    {L'𐳄', L'𐲄'},  // 00010cc4 → 00010c84
    {L'𐳅', L'𐲅'},  // 00010cc5 → 00010c85
    {L'𐳅', L'𐲙'},  // 00010cc5 → 00010c99
    {L'𐳆', L'𐲆'},  // 00010cc6 → 00010c86
    {L'𐳇', L'𐲇'},  // 00010cc7 → 00010c87
    {L'𐳈', L'𐲈'},  // 00010cc8 → 00010c88
    {L'𐳊', L'𐲊'},  // 00010cca → 00010c8a
    {L'𐳋', L'𐲋'},  // 00010ccb → 00010c8b
    {L'𐳌', L'𐲌'},  // 00010ccc → 00010c8c
    {L'𐳍', L'𐲍'},  // 00010ccd → 00010c8d
    {L'𐳎', L'𐲎'},  // 00010cce → 00010c8e
    {L'𐳏', L'𐲏'},  // 00010ccf → 00010c8f
    {L'𐳐', L'𐲐'},  // 00010cd0 → 00010c90
    {L'𐳑', L'𐲑'},  // 00010cd1 → 00010c91
    {L'𐳒', L'𐲒'},  // 00010cd2 → 00010c92
    {L'𐳓', L'𐲓'},  // 00010cd3 → 00010c93
    {L'𐳔', L'𐲔'},  // 00010cd4 → 00010c94
    {L'𐳕', L'𐲪'},  // 00010cd5 → 00010caa
    {L'𐳕', L'𐲕'},  // 00010cd5 → 00010c95
    {L'𐳖', L'𐲖'},  // 00010cd6 → 00010c96
    {L'𐳗', L'𐲗'},  // 00010cd7 → 00010c97
    {L'𐳘', L'𐲘'},  // 00010cd8 → 00010c98
    {L'𐳚', L'𐲚'},  // 00010cda → 00010c9a
    {L'𐳛', L'𐲛'},  // 00010cdb → 00010c9b
    {L'𐳜', L'𐲜'},  // 00010cdc → 00010c9c
    {L'𐳝', L'𐲝'},  // 00010cdd → 00010c9d
    {L'𐳞', L'𐲞'},  // 00010cde → 00010c9e
    {L'𐳟', L'𐲟'},  // 00010cdf → 00010c9f
    {L'𐳠', L'𐲠'},  // 00010ce0 → 00010ca0
    {L'𐳡', L'𐲡'},  // 00010ce1 → 00010ca1
    {L'𐳢', L'𐲢'},  // 00010ce2 → 00010ca2
    {L'𐳣', L'𐲣'},  // 00010ce3 → 00010ca3
    {L'𐳤', L'𐲤'},  // 00010ce4 → 00010ca4
    {L'𐳥', L'𐲥'},  // 00010ce5 → 00010ca5
    {L'𐳦', L'𐲦'},  // 00010ce6 → 00010ca6
    {L'𐳧', L'𐲧'},  // 00010ce7 → 00010ca7
    {L'𐳨', L'𐲨'},  // 00010ce8 → 00010ca8
    {L'𐳩', L'𐲩'},  // 00010ce9 → 00010ca9
    {L'𐳫', L'𐲫'},  // 00010ceb → 00010cab
    {L'𐳬', L'𐲬'},  // 00010cec → 00010cac
    {L'𐳭', L'𐲭'},  // 00010ced → 00010cad
    {L'𐳮', L'𐲮'},  // 00010cee → 00010cae
    {L'𐳯', L'𐲯'},  // 00010cef → 00010caf
    {L'𐳰', L'𐲰'},  // 00010cf0 → 00010cb0
    {L'𐳱', L'𐲱'},  // 00010cf1 → 00010cb1
    {L'𐳲', L'𐲲'},  // 00010cf2 → 00010cb2
    {L'𑣀', L'𑢠'},  // 000118c0 → 000118a0
    {L'𑣁', L'𑢡'},  // 000118c1 → 000118a1
    {L'𑣂', L'𑢢'},  // 000118c2 → 000118a2
    {L'𑣃', L'𑢣'},  // 000118c3 → 000118a3
    {L'𑣄', L'𑢤'},  // 000118c4 → 000118a4
    {L'𑣅', L'𑢥'},  // 000118c5 → 000118a5
    {L'𑣆', L'𑢦'},  // 000118c6 → 000118a6
    {L'𑣇', L'𑢧'},  // 000118c7 → 000118a7
    {L'𑣈', L'𑢨'},  // 000118c8 → 000118a8
    {L'𑣉', L'𑢩'},  // 000118c9 → 000118a9
    {L'𑣊', L'𑢪'},  // 000118ca → 000118aa
    {L'𑣋', L'𑢫'},  // 000118cb → 000118ab
    {L'𑣌', L'𑢬'},  // 000118cc → 000118ac
    {L'𑣍', L'𑢭'},  // 000118cd → 000118ad
    {L'𑣎', L'𑢮'},  // 000118ce → 000118ae
    {L'𑣏', L'𑢯'},  // 000118cf → 000118af
    {L'𑣐', L'𑢰'},  // 000118d0 → 000118b0
    {L'𑣑', L'𑢱'},  // 000118d1 → 000118b1
    {L'𑣒', L'𑢲'},  // 000118d2 → 000118b2
    {L'𑣓', L'𑢳'},  // 000118d3 → 000118b3
    {L'𑣔', L'𑢴'},  // 000118d4 → 000118b4
    {L'𑣕', L'𑢵'},  // 000118d5 → 000118b5
    {L'𑣖', L'𑢶'},  // 000118d6 → 000118b6
    {L'𑣗', L'𑢷'},  // 000118d7 → 000118b7
    {L'𑣘', L'𑢸'},  // 000118d8 → 000118b8
    {L'𑣙', L'𑢹'},  // 000118d9 → 000118b9
    {L'𑣚', L'𑢺'},  // 000118da → 000118ba
    {L'𑣛', L'𑢻'},  // 000118db → 000118bb
    {L'𑣜', L'𑢼'},  // 000118dc → 000118bc
    {L'𑣝', L'𑢽'},  // 000118dd → 000118bd
    {L'𑣞', L'𑢾'},  // 000118de → 000118be
    {L'𑣟', L'𑢿'},  // 000118df → 000118bf
    {L'𖹠', L'𖹀'},  // 00016e60 → 00016e40
    {L'𖹡', L'𖹁'},  // 00016e61 → 00016e41
    {L'𖹢', L'𖹂'},  // 00016e62 → 00016e42
    {L'𖹣', L'𖹃'},  // 00016e63 → 00016e43
    {L'𖹤', L'𖹄'},  // 00016e64 → 00016e44
    {L'𖹥', L'𖹅'},  // 00016e65 → 00016e45
    {L'𖹦', L'𖹆'},  // 00016e66 → 00016e46
    {L'𖹧', L'𖹇'},  // 00016e67 → 00016e47
    {L'𖹨', L'𖹈'},  // 00016e68 → 00016e48
    {L'𖹩', L'𖹉'},  // 00016e69 → 00016e49
    {L'𖹪', L'𖹊'},  // 00016e6a → 00016e4a
    {L'𖹫', L'𖹋'},  // 00016e6b → 00016e4b
    {L'𖹬', L'𖹌'},  // 00016e6c → 00016e4c
    {L'𖹭', L'𖹍'},  // 00016e6d → 00016e4d
    {L'𖹮', L'𖹎'},  // 00016e6e → 00016e4e
    {L'𖹯', L'𖹏'},  // 00016e6f → 00016e4f
    {L'𖹰', L'𖹐'},  // 00016e70 → 00016e50
    {L'𖹱', L'𖹑'},  // 00016e71 → 00016e51
    {L'𖹲', L'𖹒'},  // 00016e72 → 00016e52
    {L'𖹳', L'𖹓'},  // 00016e73 → 00016e53
    {L'𖹴', L'𖹔'},  // 00016e74 → 00016e54
    {L'𖹵', L'𖹕'},  // 00016e75 → 00016e55
    {L'𖹶', L'𖹖'},  // 00016e76 → 00016e56
    {L'𖹷', L'𖹗'},  // 00016e77 → 00016e57
    {L'𖹸', L'𖹘'},  // 00016e78 → 00016e58
    {L'𖹹', L'𖹙'},  // 00016e79 → 00016e59
    {L'𖹺', L'𖹚'},  // 00016e7a → 00016e5a
    {L'𖹻', L'𖹛'},  // 00016e7b → 00016e5b
    {L'𖹼', L'𖹜'},  // 00016e7c → 00016e5c
    {L'𖹽', L'𖹝'},  // 00016e7d → 00016e5d
    {L'𖹾', L'𖹞'},  // 00016e7e → 00016e5e
    {L'𖹿', L'𖹟'},  // 00016e7f → 00016e5f
    {L'𝐚', L'𝐀'},        // 0001d41a → 0001d400
    {L'𝐛', L'𝐁'},        // 0001d41b → 0001d401
    {L'𝐜', L'𝐂'},        // 0001d41c → 0001d402
    {L'𝐝', L'𝐃'},        // 0001d41d → 0001d403
    {L'𝐞', L'𝐄'},        // 0001d41e → 0001d404
    {L'𝐟', L'𝐅'},        // 0001d41f → 0001d405
    {L'𝐠', L'𝐆'},        // 0001d420 → 0001d406
    {L'𝐡', L'𝐇'},        // 0001d421 → 0001d407
    {L'𝐢', L'𝐈'},        // 0001d422 → 0001d408
    {L'𝐣', L'𝐉'},        // 0001d423 → 0001d409
    {L'𝐤', L'𝐊'},        // 0001d424 → 0001d40a
    {L'𝐥', L'𝐋'},        // 0001d425 → 0001d40b
    {L'𝐦', L'𝐌'},        // 0001d426 → 0001d40c
    {L'𝐧', L'𝐍'},        // 0001d427 → 0001d40d
    {L'𝐨', L'𝐎'},        // 0001d428 → 0001d40e
    {L'𝐩', L'𝐏'},        // 0001d429 → 0001d40f
    {L'𝐪', L'𝐐'},        // 0001d42a → 0001d410
    {L'𝐫', L'𝐑'},        // 0001d42b → 0001d411
    {L'𝐬', L'𝐒'},        // 0001d42c → 0001d412
    {L'𝐭', L'𝐓'},        // 0001d42d → 0001d413
    {L'𝐮', L'𝐔'},        // 0001d42e → 0001d414
    {L'𝐯', L'𝐕'},        // 0001d42f → 0001d415
    {L'𝐰', L'𝐖'},        // 0001d430 → 0001d416
    {L'𝐱', L'𝐗'},        // 0001d431 → 0001d417
    {L'𝐲', L'𝐘'},        // 0001d432 → 0001d418
    {L'𝐳', L'𝐙'},        // 0001d433 → 0001d419
    {L'𝑎', L'𝐴'},        // 0001d44e → 0001d434
    {L'𝑏', L'𝐵'},        // 0001d44f → 0001d435
    {L'𝑐', L'𝐶'},        // 0001d450 → 0001d436
    {L'𝑑', L'𝐷'},        // 0001d451 → 0001d437
    {L'𝑒', L'𝐸'},        // 0001d452 → 0001d438
    {L'𝑓', L'𝐹'},        // 0001d453 → 0001d439
    {L'𝑔', L'𝐺'},        // 0001d454 → 0001d43a
    {L'𝑖', L'𝐼'},        // 0001d456 → 0001d43c
    {L'𝑗', L'𝐽'},        // 0001d457 → 0001d43d
    {L'𝑘', L'𝐾'},        // 0001d458 → 0001d43e
    {L'𝑙', L'𝐿'},        // 0001d459 → 0001d43f
    {L'𝑚', L'𝑀'},        // 0001d45a → 0001d440
    {L'𝑛', L'𝑁'},        // 0001d45b → 0001d441
    {L'𝑜', L'𝑂'},        // 0001d45c → 0001d442
    {L'𝑝', L'𝑃'},        // 0001d45d → 0001d443
    {L'𝑞', L'𝑄'},        // 0001d45e → 0001d444
    {L'𝑟', L'𝑅'},        // 0001d45f → 0001d445
    {L'𝑠', L'𝑆'},        // 0001d460 → 0001d446
    {L'𝑡', L'𝑇'},        // 0001d461 → 0001d447
    {L'𝑢', L'𝑈'},        // 0001d462 → 0001d448
    {L'𝑣', L'𝑉'},        // 0001d463 → 0001d449
    {L'𝑤', L'𝑊'},        // 0001d464 → 0001d44a
    {L'𝑥', L'𝑋'},        // 0001d465 → 0001d44b
    {L'𝑦', L'𝑌'},        // 0001d466 → 0001d44c
    {L'𝑧', L'𝑍'},        // 0001d467 → 0001d44d
    {L'𝒂', L'𝘼'},        // 0001d482 → 0001d63c
    {L'𝒂', L'𝑨'},        // 0001d482 → 0001d468
    {L'𝒃', L'𝘽'},        // 0001d483 → 0001d63d
    {L'𝒃', L'𝑩'},        // 0001d483 → 0001d469
    {L'𝒄', L'𝘾'},        // 0001d484 → 0001d63e
    {L'𝒄', L'𝑪'},        // 0001d484 → 0001d46a
    {L'𝒅', L'𝘿'},        // 0001d485 → 0001d63f
    {L'𝒅', L'𝑫'},        // 0001d485 → 0001d46b
    {L'𝒆', L'𝙀'},        // 0001d486 → 0001d640
    {L'𝒆', L'𝑬'},        // 0001d486 → 0001d46c
    {L'𝒇', L'𝙁'},        // 0001d487 → 0001d641
    {L'𝒇', L'𝑭'},        // 0001d487 → 0001d46d
    {L'𝒈', L'𝙂'},        // 0001d488 → 0001d642
    {L'𝒈', L'𝑮'},        // 0001d488 → 0001d46e
    {L'𝒉', L'𝙃'},        // 0001d489 → 0001d643
    {L'𝒉', L'𝑯'},        // 0001d489 → 0001d46f
    {L'𝒊', L'𝙄'},        // 0001d48a → 0001d644
    {L'𝒊', L'𝑰'},        // 0001d48a → 0001d470
    {L'𝒋', L'𝙅'},        // 0001d48b → 0001d645
    {L'𝒋', L'𝑱'},        // 0001d48b → 0001d471
    {L'𝒌', L'𝙆'},        // 0001d48c → 0001d646
    {L'𝒌', L'𝑲'},        // 0001d48c → 0001d472
    {L'𝒍', L'𝙇'},        // 0001d48d → 0001d647
    {L'𝒍', L'𝑳'},        // 0001d48d → 0001d473
    {L'𝒎', L'𝙈'},        // 0001d48e → 0001d648
    {L'𝒎', L'𝑴'},        // 0001d48e → 0001d474
    {L'𝒏', L'𝙉'},        // 0001d48f → 0001d649
    {L'𝒏', L'𝑵'},        // 0001d48f → 0001d475
    {L'𝒐', L'𝑶'},        // 0001d490 → 0001d476
    {L'𝒐', L'𝙊'},        // 0001d490 → 0001d64a
    {L'𝒑', L'𝙋'},        // 0001d491 → 0001d64b
    {L'𝒑', L'𝑷'},        // 0001d491 → 0001d477
    {L'𝒒', L'𝑸'},        // 0001d492 → 0001d478
    {L'𝒒', L'𝙌'},        // 0001d492 → 0001d64c
    {L'𝒓', L'𝙍'},        // 0001d493 → 0001d64d
    {L'𝒓', L'𝑹'},        // 0001d493 → 0001d479
    {L'𝒔', L'𝙎'},        // 0001d494 → 0001d64e
    {L'𝒔', L'𝑺'},        // 0001d494 → 0001d47a
    {L'𝒕', L'𝙏'},        // 0001d495 → 0001d64f
    {L'𝒕', L'𝑻'},        // 0001d495 → 0001d47b
    {L'𝒖', L'𝙐'},        // 0001d496 → 0001d650
    {L'𝒖', L'𝑼'},        // 0001d496 → 0001d47c
    {L'𝒗', L'𝙑'},        // 0001d497 → 0001d651
    {L'𝒗', L'𝑽'},        // 0001d497 → 0001d47d
    {L'𝒘', L'𝑾'},        // 0001d498 → 0001d47e
    {L'𝒘', L'𝙒'},        // 0001d498 → 0001d652
    {L'𝒙', L'𝑿'},        // 0001d499 → 0001d47f
    {L'𝒙', L'𝙓'},        // 0001d499 → 0001d653
    {L'𝒚', L'𝒀'},        // 0001d49a → 0001d480
    {L'𝒚', L'𝙔'},        // 0001d49a → 0001d654
    {L'𝒛', L'𝒁'},        // 0001d49b → 0001d481
    {L'𝒛', L'𝙕'},        // 0001d49b → 0001d655
    {L'𝒶', L'𝒜'},        // 0001d4b6 → 0001d49c
    {L'𝒷', L'ℬ'},        // 0001d4b7 → 0000212c
    {L'𝒸', L'𝒞'},        // 0001d4b8 → 0001d49e
    {L'𝒹', L'𝒟'},        // 0001d4b9 → 0001d49f
    {L'𝒻', L'ℱ'},        // 0001d4bb → 00002131
    {L'𝒽', L'ℋ'},        // 0001d4bd → 0000210b
    {L'𝒾', L'ℐ'},        // 0001d4be → 00002110
    {L'𝒿', L'𝒥'},        // 0001d4bf → 0001d4a5
    {L'𝓀', L'𝒦'},        // 0001d4c0 → 0001d4a6
    {L'𝓂', L'ℳ'},        // 0001d4c2 → 00002133
    {L'𝓃', L'𝒩'},        // 0001d4c3 → 0001d4a9
    {L'𝓅', L'𝒫'},        // 0001d4c5 → 0001d4ab
    {L'𝓆', L'𝒬'},        // 0001d4c6 → 0001d4ac
    {L'𝓇', L'ℛ'},        // 0001d4c7 → 0000211b
    {L'𝓈', L'𝒮'},        // 0001d4c8 → 0001d4ae
    {L'𝓉', L'𝒯'},        // 0001d4c9 → 0001d4af
    {L'𝓊', L'𝒰'},        // 0001d4ca → 0001d4b0
    {L'𝓋', L'𝒱'},        // 0001d4cb → 0001d4b1
    {L'𝓌', L'𝒲'},        // 0001d4cc → 0001d4b2
    {L'𝓍', L'𝒳'},        // 0001d4cd → 0001d4b3
    {L'𝓎', L'𝒴'},        // 0001d4ce → 0001d4b4
    {L'𝓏', L'𝒵'},        // 0001d4cf → 0001d4b5
    {L'𝓪', L'𝓐'},        // 0001d4ea → 0001d4d0
    {L'𝓫', L'𝓑'},        // 0001d4eb → 0001d4d1
    {L'𝓬', L'𝓒'},        // 0001d4ec → 0001d4d2
    {L'𝓭', L'𝓓'},        // 0001d4ed → 0001d4d3
    {L'𝓮', L'𝓔'},        // 0001d4ee → 0001d4d4
    {L'𝓯', L'𝓕'},        // 0001d4ef → 0001d4d5
    {L'𝓰', L'𝓖'},        // 0001d4f0 → 0001d4d6
    {L'𝓱', L'𝓗'},        // 0001d4f1 → 0001d4d7
    {L'𝓲', L'𝓘'},        // 0001d4f2 → 0001d4d8
    {L'𝓳', L'𝓙'},        // 0001d4f3 → 0001d4d9
    {L'𝓴', L'𝓚'},        // 0001d4f4 → 0001d4da
    {L'𝓵', L'𝓛'},        // 0001d4f5 → 0001d4db
    {L'𝓶', L'𝓜'},        // 0001d4f6 → 0001d4dc
    {L'𝓷', L'𝓝'},        // 0001d4f7 → 0001d4dd
    {L'𝓸', L'𝓞'},        // 0001d4f8 → 0001d4de
    {L'𝓹', L'𝓟'},        // 0001d4f9 → 0001d4df
    {L'𝓺', L'𝓠'},        // 0001d4fa → 0001d4e0
    {L'𝓻', L'𝓡'},        // 0001d4fb → 0001d4e1
    {L'𝓼', L'𝓢'},        // 0001d4fc → 0001d4e2
    {L'𝓽', L'𝓣'},        // 0001d4fd → 0001d4e3
    {L'𝓾', L'𝓤'},        // 0001d4fe → 0001d4e4
    {L'𝓿', L'𝓥'},        // 0001d4ff → 0001d4e5
    {L'𝔀', L'𝓦'},        // 0001d500 → 0001d4e6
    {L'𝔁', L'𝓧'},        // 0001d501 → 0001d4e7
    {L'𝔂', L'𝓨'},        // 0001d502 → 0001d4e8
    {L'𝔃', L'𝓩'},        // 0001d503 → 0001d4e9
    {L'𝔞', L'𝔄'},        // 0001d51e → 0001d504
    {L'𝔟', L'𝔅'},        // 0001d51f → 0001d505
    {L'𝔡', L'𝔇'},        // 0001d521 → 0001d507
    {L'𝔢', L'𝔈'},        // 0001d522 → 0001d508
    {L'𝔣', L'𝔉'},        // 0001d523 → 0001d509
    {L'𝔤', L'𝔊'},        // 0001d524 → 0001d50a
    {L'𝔧', L'𝔍'},        // 0001d527 → 0001d50d
    {L'𝔨', L'𝔎'},        // 0001d528 → 0001d50e
    {L'𝔩', L'𝔏'},        // 0001d529 → 0001d50f
    {L'𝔪', L'𝔐'},        // 0001d52a → 0001d510
    {L'𝔫', L'𝔑'},        // 0001d52b → 0001d511
    {L'𝔬', L'𝔒'},        // 0001d52c → 0001d512
    {L'𝔭', L'𝔓'},        // 0001d52d → 0001d513
    {L'𝔮', L'𝔔'},        // 0001d52e → 0001d514
    {L'𝔰', L'𝔖'},        // 0001d530 → 0001d516
    {L'𝔱', L'𝔗'},        // 0001d531 → 0001d517
    {L'𝔲', L'𝔘'},        // 0001d532 → 0001d518
    {L'𝔳', L'𝔙'},        // 0001d533 → 0001d519
    {L'𝔴', L'𝔚'},        // 0001d534 → 0001d51a
    {L'𝔵', L'𝔛'},        // 0001d535 → 0001d51b
    {L'𝔶', L'𝔜'},        // 0001d536 → 0001d51c
    {L'𝕒', L'𝔸'},        // 0001d552 → 0001d538
    {L'𝕓', L'𝔹'},        // 0001d553 → 0001d539
    {L'𝕔', L'ℂ'},        // 0001d554 → 00002102
    {L'𝕕', L'𝔻'},        // 0001d555 → 0001d53b
    {L'𝕖', L'𝔼'},        // 0001d556 → 0001d53c
    {L'𝕗', L'𝔽'},        // 0001d557 → 0001d53d
    {L'𝕙', L'ℍ'},        // 0001d559 → 0000210d
    {L'𝕚', L'𝕀'},        // 0001d55a → 0001d540
    {L'𝕛', L'𝕁'},        // 0001d55b → 0001d541
    {L'𝕜', L'𝕂'},        // 0001d55c → 0001d542
    {L'𝕝', L'𝕃'},        // 0001d55d → 0001d543
    {L'𝕞', L'𝕄'},        // 0001d55e → 0001d544
    {L'𝕟', L'ℕ'},        // 0001d55f → 00002115
    {L'𝕠', L'𝕆'},        // 0001d560 → 0001d546
    {L'𝕢', L'ℚ'},        // 0001d562 → 0000211a
    {L'𝕣', L'ℝ'},        // 0001d563 → 0000211d
    {L'𝕤', L'𝕊'},        // 0001d564 → 0001d54a
    {L'𝕥', L'𝕋'},        // 0001d565 → 0001d54b
    {L'𝕦', L'𝕌'},        // 0001d566 → 0001d54c
    {L'𝕧', L'𝕍'},        // 0001d567 → 0001d54d
    {L'𝕨', L'𝕎'},        // 0001d568 → 0001d54e
    {L'𝕩', L'𝕏'},        // 0001d569 → 0001d54f
    {L'𝕪', L'𝕐'},        // 0001d56a → 0001d550
    {L'𝕫', L'ℤ'},        // 0001d56b → 00002124
    {L'𝖆', L'𝕬'},        // 0001d586 → 0001d56c
    {L'𝖇', L'𝕭'},        // 0001d587 → 0001d56d
    {L'𝖈', L'𝕮'},        // 0001d588 → 0001d56e
    {L'𝖉', L'𝕯'},        // 0001d589 → 0001d56f
    {L'𝖊', L'𝕰'},        // 0001d58a → 0001d570
    {L'𝖋', L'𝕱'},        // 0001d58b → 0001d571
    {L'𝖌', L'𝕲'},        // 0001d58c → 0001d572
    {L'𝖍', L'𝕳'},        // 0001d58d → 0001d573
    {L'𝖎', L'𝕴'},        // 0001d58e → 0001d574
    {L'𝖏', L'𝕵'},        // 0001d58f → 0001d575
    {L'𝖐', L'𝕶'},        // 0001d590 → 0001d576
    {L'𝖑', L'𝕷'},        // 0001d591 → 0001d577
    {L'𝖒', L'𝕸'},        // 0001d592 → 0001d578
    {L'𝖓', L'𝕹'},        // 0001d593 → 0001d579
    {L'𝖔', L'𝕺'},        // 0001d594 → 0001d57a
    {L'𝖕', L'𝕻'},        // 0001d595 → 0001d57b
    {L'𝖖', L'𝕼'},        // 0001d596 → 0001d57c
    {L'𝖗', L'𝕽'},        // 0001d597 → 0001d57d
    {L'𝖘', L'𝕾'},        // 0001d598 → 0001d57e
    {L'𝖙', L'𝕿'},        // 0001d599 → 0001d57f
    {L'𝖚', L'𝖀'},        // 0001d59a → 0001d580
    {L'𝖛', L'𝖁'},        // 0001d59b → 0001d581
    {L'𝖜', L'𝖂'},        // 0001d59c → 0001d582
    {L'𝖝', L'𝖃'},        // 0001d59d → 0001d583
    {L'𝖞', L'𝖄'},        // 0001d59e → 0001d584
    {L'𝖟', L'𝖅'},        // 0001d59f → 0001d585
    {L'𝖺', L'𝖠'},        // 0001d5ba → 0001d5a0
    {L'𝖻', L'𝖡'},        // 0001d5bb → 0001d5a1
    {L'𝖼', L'𝖢'},        // 0001d5bc → 0001d5a2
    {L'𝖽', L'𝖣'},        // 0001d5bd → 0001d5a3
    {L'𝖾', L'𝖤'},        // 0001d5be → 0001d5a4
    {L'𝖿', L'𝖥'},        // 0001d5bf → 0001d5a5
    {L'𝗀', L'𝖦'},        // 0001d5c0 → 0001d5a6
    {L'𝗁', L'𝖧'},        // 0001d5c1 → 0001d5a7
    {L'𝗂', L'𝖨'},        // 0001d5c2 → 0001d5a8
    {L'𝗃', L'𝖩'},        // 0001d5c3 → 0001d5a9
    {L'𝗄', L'𝖪'},        // 0001d5c4 → 0001d5aa
    {L'𝗅', L'𝖫'},        // 0001d5c5 → 0001d5ab
    {L'𝗆', L'𝖬'},        // 0001d5c6 → 0001d5ac
    {L'𝗇', L'𝖭'},        // 0001d5c7 → 0001d5ad
    {L'𝗈', L'𝖮'},        // 0001d5c8 → 0001d5ae
    {L'𝗉', L'𝖯'},        // 0001d5c9 → 0001d5af
    {L'𝗊', L'𝖰'},        // 0001d5ca → 0001d5b0
    {L'𝗋', L'𝖱'},        // 0001d5cb → 0001d5b1
    {L'𝗌', L'𝖲'},        // 0001d5cc → 0001d5b2
    {L'𝗍', L'𝖳'},        // 0001d5cd → 0001d5b3
    {L'𝗎', L'𝖴'},        // 0001d5ce → 0001d5b4
    {L'𝗏', L'𝖵'},        // 0001d5cf → 0001d5b5
    {L'𝗐', L'𝖶'},        // 0001d5d0 → 0001d5b6
    {L'𝗑', L'𝖷'},        // 0001d5d1 → 0001d5b7
    {L'𝗒', L'𝖸'},        // 0001d5d2 → 0001d5b8
    {L'𝗓', L'𝖹'},        // 0001d5d3 → 0001d5b9
    {L'𝗮', L'𝗔'},        // 0001d5ee → 0001d5d4
    {L'𝗯', L'𝗕'},        // 0001d5ef → 0001d5d5
    {L'𝗰', L'𝗖'},        // 0001d5f0 → 0001d5d6
    {L'𝗱', L'𝗗'},        // 0001d5f1 → 0001d5d7
    {L'𝗲', L'𝗘'},        // 0001d5f2 → 0001d5d8
    {L'𝗳', L'𝗙'},        // 0001d5f3 → 0001d5d9
    {L'𝗴', L'𝗚'},        // 0001d5f4 → 0001d5da
    {L'𝗵', L'𝗛'},        // 0001d5f5 → 0001d5db
    {L'𝗶', L'𝗜'},        // 0001d5f6 → 0001d5dc
    {L'𝗷', L'𝗝'},        // 0001d5f7 → 0001d5dd
    {L'𝗸', L'𝗞'},        // 0001d5f8 → 0001d5de
    {L'𝗹', L'𝗟'},        // 0001d5f9 → 0001d5df
    {L'𝗺', L'𝗠'},        // 0001d5fa → 0001d5e0
    {L'𝗻', L'𝗡'},        // 0001d5fb → 0001d5e1
    {L'𝗼', L'𝗢'},        // 0001d5fc → 0001d5e2
    {L'𝗽', L'𝗣'},        // 0001d5fd → 0001d5e3
    {L'𝗾', L'𝗤'},        // 0001d5fe → 0001d5e4
    {L'𝗿', L'𝗥'},        // 0001d5ff → 0001d5e5
    {L'𝘀', L'𝗦'},        // 0001d600 → 0001d5e6
    {L'𝘁', L'𝗧'},        // 0001d601 → 0001d5e7
    {L'𝘂', L'𝗨'},        // 0001d602 → 0001d5e8
    {L'𝘃', L'𝗩'},        // 0001d603 → 0001d5e9
    {L'𝘄', L'𝗪'},        // 0001d604 → 0001d5ea
    {L'𝘅', L'𝗫'},        // 0001d605 → 0001d5eb
    {L'𝘆', L'𝗬'},        // 0001d606 → 0001d5ec
    {L'𝘇', L'𝗭'},        // 0001d607 → 0001d5ed
    {L'𝘢', L'𝘈'},        // 0001d622 → 0001d608
    {L'𝘣', L'𝘉'},        // 0001d623 → 0001d609
    {L'𝘤', L'𝘊'},        // 0001d624 → 0001d60a
    {L'𝘥', L'𝘋'},        // 0001d625 → 0001d60b
    {L'𝘦', L'𝘌'},        // 0001d626 → 0001d60c
    {L'𝘧', L'𝘍'},        // 0001d627 → 0001d60d
    {L'𝘨', L'𝘎'},        // 0001d628 → 0001d60e
    {L'𝘩', L'𝘏'},        // 0001d629 → 0001d60f
    {L'𝘪', L'𝘐'},        // 0001d62a → 0001d610
    {L'𝘫', L'𝘑'},        // 0001d62b → 0001d611
    {L'𝘬', L'𝘒'},        // 0001d62c → 0001d612
    {L'𝘭', L'𝘓'},        // 0001d62d → 0001d613
    {L'𝘮', L'𝘔'},        // 0001d62e → 0001d614
    {L'𝘯', L'𝘕'},        // 0001d62f → 0001d615
    {L'𝘰', L'𝘖'},        // 0001d630 → 0001d616
    {L'𝘱', L'𝘗'},        // 0001d631 → 0001d617
    {L'𝘲', L'𝘘'},        // 0001d632 → 0001d618
    {L'𝘳', L'𝘙'},        // 0001d633 → 0001d619
    {L'𝘴', L'𝘚'},        // 0001d634 → 0001d61a
    {L'𝘵', L'𝘛'},        // 0001d635 → 0001d61b
    {L'𝘶', L'𝘜'},        // 0001d636 → 0001d61c
    {L'𝘷', L'𝘝'},        // 0001d637 → 0001d61d
    {L'𝘸', L'𝘞'},        // 0001d638 → 0001d61e
    {L'𝘹', L'𝘟'},        // 0001d639 → 0001d61f
    {L'𝘺', L'𝘠'},        // 0001d63a → 0001d620
    {L'𝘻', L'𝘡'},        // 0001d63b → 0001d621
    {L'𝚊', L'𝙰'},        // 0001d68a → 0001d670
    {L'𝚋', L'𝙱'},        // 0001d68b → 0001d671
    {L'𝚌', L'𝙲'},        // 0001d68c → 0001d672
    {L'𝚍', L'𝙳'},        // 0001d68d → 0001d673
    {L'𝚎', L'𝙴'},        // 0001d68e → 0001d674
    {L'𝚏', L'𝙵'},        // 0001d68f → 0001d675
    {L'𝚐', L'𝙶'},        // 0001d690 → 0001d676
    {L'𝚑', L'𝙷'},        // 0001d691 → 0001d677
    {L'𝚒', L'𝙸'},        // 0001d692 → 0001d678
    {L'𝚓', L'𝙹'},        // 0001d693 → 0001d679
    {L'𝚔', L'𝙺'},        // 0001d694 → 0001d67a
    {L'𝚕', L'𝙻'},        // 0001d695 → 0001d67b
    {L'𝚖', L'𝙼'},        // 0001d696 → 0001d67c
    {L'𝚗', L'𝙽'},        // 0001d697 → 0001d67d
    {L'𝚘', L'𝙾'},        // 0001d698 → 0001d67e
    {L'𝚙', L'𝙿'},        // 0001d699 → 0001d67f
    {L'𝚚', L'𝚀'},        // 0001d69a → 0001d680
    {L'𝚛', L'𝚁'},        // 0001d69b → 0001d681
    {L'𝚜', L'𝚂'},        // 0001d69c → 0001d682
    {L'𝚝', L'𝚃'},        // 0001d69d → 0001d683
    {L'𝚞', L'𝚄'},        // 0001d69e → 0001d684
    {L'𝚟', L'𝚅'},        // 0001d69f → 0001d685
    {L'𝚠', L'𝚆'},        // 0001d6a0 → 0001d686
    {L'𝚡', L'𝚇'},        // 0001d6a1 → 0001d687
    {L'𝚢', L'𝚈'},        // 0001d6a2 → 0001d688
    {L'𝚣', L'𝚉'},        // 0001d6a3 → 0001d689
    {L'𝛂', L'𝚨'},        // 0001d6c2 → 0001d6a8
    {L'𝛃', L'𝚩'},        // 0001d6c3 → 0001d6a9
    {L'𝛄', L'𝚪'},        // 0001d6c4 → 0001d6aa
    {L'𝛅', L'𝚫'},        // 0001d6c5 → 0001d6ab
    {L'𝛆', L'𝚬'},        // 0001d6c6 → 0001d6ac
    {L'𝛇', L'𝚭'},        // 0001d6c7 → 0001d6ad
    {L'𝛈', L'𝚮'},        // 0001d6c8 → 0001d6ae
    {L'𝛉', L'𝚯'},        // 0001d6c9 → 0001d6af
    {L'𝛊', L'𝚰'},        // 0001d6ca → 0001d6b0
    {L'𝛋', L'𝚱'},        // 0001d6cb → 0001d6b1
    {L'𝛌', L'𝚲'},        // 0001d6cc → 0001d6b2
    {L'𝛍', L'𝚳'},        // 0001d6cd → 0001d6b3
    {L'𝛎', L'𝚴'},        // 0001d6ce → 0001d6b4
    {L'𝛏', L'𝚵'},        // 0001d6cf → 0001d6b5
    {L'𝛐', L'𝚶'},        // 0001d6d0 → 0001d6b6
    {L'𝛑', L'𝚷'},        // 0001d6d1 → 0001d6b7
    {L'𝛒', L'𝚸'},        // 0001d6d2 → 0001d6b8
    {L'𝛔', L'𝚺'},        // 0001d6d4 → 0001d6ba
    {L'𝛕', L'𝚻'},        // 0001d6d5 → 0001d6bb
    {L'𝛖', L'𝚼'},        // 0001d6d6 → 0001d6bc
    {L'𝛗', L'𝚽'},        // 0001d6d7 → 0001d6bd
    {L'𝛘', L'𝚾'},        // 0001d6d8 → 0001d6be
    {L'𝛙', L'𝚿'},        // 0001d6d9 → 0001d6bf
    {L'𝛚', L'𝛀'},        // 0001d6da → 0001d6c0
    {L'𝛼', L'𝛢'},        // 0001d6fc → 0001d6e2
    {L'𝛽', L'𝛣'},        // 0001d6fd → 0001d6e3
    {L'𝛾', L'𝛤'},        // 0001d6fe → 0001d6e4
    {L'𝛿', L'𝛥'},        // 0001d6ff → 0001d6e5
    {L'𝜀', L'𝛦'},        // 0001d700 → 0001d6e6
    {L'𝜁', L'𝛧'},        // 0001d701 → 0001d6e7
    {L'𝜂', L'𝛨'},        // 0001d702 → 0001d6e8
    {L'𝜃', L'𝛩'},        // 0001d703 → 0001d6e9
    {L'𝜄', L'𝛪'},        // 0001d704 → 0001d6ea
    {L'𝜅', L'𝛫'},        // 0001d705 → 0001d6eb
    {L'𝜆', L'𝛬'},        // 0001d706 → 0001d6ec
    {L'𝜇', L'𝛭'},        // 0001d707 → 0001d6ed
    {L'𝜈', L'𝛮'},        // 0001d708 → 0001d6ee
    {L'𝜉', L'𝛯'},        // 0001d709 → 0001d6ef
    {L'𝜊', L'𝛰'},        // 0001d70a → 0001d6f0
    {L'𝜋', L'𝛱'},        // 0001d70b → 0001d6f1
    {L'𝜌', L'𝛲'},        // 0001d70c → 0001d6f2
    {L'𝜎', L'𝛴'},        // 0001d70e → 0001d6f4
    {L'𝜏', L'𝛵'},        // 0001d70f → 0001d6f5
    {L'𝜐', L'𝛶'},        // 0001d710 → 0001d6f6
    {L'𝜑', L'𝛷'},        // 0001d711 → 0001d6f7
    {L'𝜒', L'𝛸'},        // 0001d712 → 0001d6f8
    {L'𝜓', L'𝛹'},        // 0001d713 → 0001d6f9
    {L'𝜔', L'𝛺'},        // 0001d714 → 0001d6fa
    {L'𝜗', L'𝛳'},        // 0001d717 → 0001d6f3
    {L'𝜶', L'𝜜'},        // 0001d736 → 0001d71c
    {L'𝜶', L'𝞐'},        // 0001d736 → 0001d790
    {L'𝜷', L'𝜝'},        // 0001d737 → 0001d71d
    {L'𝜷', L'𝞑'},        // 0001d737 → 0001d791
    {L'𝜸', L'𝞒'},        // 0001d738 → 0001d792
    {L'𝜸', L'𝜞'},        // 0001d738 → 0001d71e
    {L'𝜹', L'𝜟'},        // 0001d739 → 0001d71f
    {L'𝜹', L'𝞓'},        // 0001d739 → 0001d793
    {L'𝜺', L'𝜠'},        // 0001d73a → 0001d720
    {L'𝜺', L'𝞔'},        // 0001d73a → 0001d794
    {L'𝜻', L'𝜡'},        // 0001d73b → 0001d721
    {L'𝜻', L'𝞕'},        // 0001d73b → 0001d795
    {L'𝜼', L'𝜢'},        // 0001d73c → 0001d722
    {L'𝜼', L'𝞖'},        // 0001d73c → 0001d796
    {L'𝜽', L'𝜣'},        // 0001d73d → 0001d723
    {L'𝜽', L'𝞗'},        // 0001d73d → 0001d797
    {L'𝜾', L'𝜤'},        // 0001d73e → 0001d724
    {L'𝜾', L'𝞘'},        // 0001d73e → 0001d798
    {L'𝜿', L'𝜥'},        // 0001d73f → 0001d725
    {L'𝜿', L'𝞙'},        // 0001d73f → 0001d799
    {L'𝝀', L'𝜦'},        // 0001d740 → 0001d726
    {L'𝝀', L'𝞚'},        // 0001d740 → 0001d79a
    {L'𝝁', L'𝞛'},        // 0001d741 → 0001d79b
    {L'𝝁', L'𝜧'},        // 0001d741 → 0001d727
    {L'𝝂', L'𝞜'},        // 0001d742 → 0001d79c
    {L'𝝂', L'𝜨'},        // 0001d742 → 0001d728
    {L'𝝃', L'𝞝'},        // 0001d743 → 0001d79d
    {L'𝝃', L'𝜩'},        // 0001d743 → 0001d729
    {L'𝝄', L'𝞞'},        // 0001d744 → 0001d79e
    {L'𝝄', L'𝜪'},        // 0001d744 → 0001d72a
    {L'𝝅', L'𝞟'},        // 0001d745 → 0001d79f
    {L'𝝅', L'𝜫'},        // 0001d745 → 0001d72b
    {L'𝝆', L'𝞠'},        // 0001d746 → 0001d7a0
    {L'𝝆', L'𝜬'},        // 0001d746 → 0001d72c
    {L'𝝈', L'𝞢'},        // 0001d748 → 0001d7a2
    {L'𝝈', L'𝜮'},        // 0001d748 → 0001d72e
    {L'𝝉', L'𝜯'},        // 0001d749 → 0001d72f
    {L'𝝉', L'𝞣'},        // 0001d749 → 0001d7a3
    {L'𝝊', L'𝞤'},        // 0001d74a → 0001d7a4
    {L'𝝊', L'𝜰'},        // 0001d74a → 0001d730
    {L'𝝋', L'𝜱'},        // 0001d74b → 0001d731
    {L'𝝋', L'𝞥'},        // 0001d74b → 0001d7a5
    {L'𝝌', L'𝜲'},        // 0001d74c → 0001d732
    {L'𝝌', L'𝞦'},        // 0001d74c → 0001d7a6
    {L'𝝍', L'𝜳'},        // 0001d74d → 0001d733
    {L'𝝍', L'𝞧'},        // 0001d74d → 0001d7a7
    {L'𝝎', L'𝜴'},        // 0001d74e → 0001d734
    {L'𝝎', L'𝞨'},        // 0001d74e → 0001d7a8
    {L'𝝑', L'𝜭'},        // 0001d751 → 0001d72d
    {L'𝝰', L'𝝖'},        // 0001d770 → 0001d756
    {L'𝝱', L'𝝗'},        // 0001d771 → 0001d757
    {L'𝝲', L'𝝘'},        // 0001d772 → 0001d758
    {L'𝝳', L'𝝙'},        // 0001d773 → 0001d759
    {L'𝝴', L'𝝚'},        // 0001d774 → 0001d75a
    {L'𝝵', L'𝝛'},        // 0001d775 → 0001d75b
    {L'𝝶', L'𝝜'},        // 0001d776 → 0001d75c
    {L'𝝷', L'𝝝'},        // 0001d777 → 0001d75d
    {L'𝝸', L'𝝞'},        // 0001d778 → 0001d75e
    {L'𝝹', L'𝝟'},        // 0001d779 → 0001d75f
    {L'𝝺', L'𝝠'},        // 0001d77a → 0001d760
    {L'𝝻', L'𝝡'},        // 0001d77b → 0001d761
    {L'𝝼', L'𝝢'},        // 0001d77c → 0001d762
    {L'𝝽', L'𝝣'},        // 0001d77d → 0001d763
    {L'𝝾', L'𝝤'},        // 0001d77e → 0001d764
    {L'𝝿', L'𝝥'},        // 0001d77f → 0001d765
    {L'𝞀', L'𝝦'},        // 0001d780 → 0001d766
    {L'𝞂', L'𝝨'},        // 0001d782 → 0001d768
    {L'𝞃', L'𝝩'},        // 0001d783 → 0001d769
    {L'𝞄', L'𝝪'},        // 0001d784 → 0001d76a
    {L'𝞅', L'𝝫'},        // 0001d785 → 0001d76b
    {L'𝞆', L'𝝬'},        // 0001d786 → 0001d76c
    {L'𝞇', L'𝝭'},        // 0001d787 → 0001d76d
    {L'𝞈', L'𝝮'},        // 0001d788 → 0001d76e
    {L'𝟅', L'𝞡'},        // 0001d7c5 → 0001d7a1
    {L'𝟅', L'𝝧'},        // 0001d7c5 → 0001d767
    {L'𝟋', L'𝟊'},        // 0001d7cb → 0001d7ca
    {L'𞤢', L'𞤀'},  // 0001e922 → 0001e900
    {L'𞤣', L'𞤁'},  // 0001e923 → 0001e901
    {L'𞤤', L'𞤂'},  // 0001e924 → 0001e902
    {L'𞤥', L'𞤃'},  // 0001e925 → 0001e903
    {L'𞤦', L'𞤄'},  // 0001e926 → 0001e904
    {L'𞤧', L'𞤅'},  // 0001e927 → 0001e905
    {L'𞤨', L'𞤆'},  // 0001e928 → 0001e906
    {L'𞤩', L'𞤇'},  // 0001e929 → 0001e907
    {L'𞤪', L'𞤈'},  // 0001e92a → 0001e908
    {L'𞤫', L'𞤉'},  // 0001e92b → 0001e909
    {L'𞤬', L'𞤊'},  // 0001e92c → 0001e90a
    {L'𞤭', L'𞤋'},  // 0001e92d → 0001e90b
    {L'𞤮', L'𞤌'},  // 0001e92e → 0001e90c
    {L'𞤯', L'𞤍'},  // 0001e92f → 0001e90d
    {L'𞤰', L'𞤎'},  // 0001e930 → 0001e90e
    {L'𞤱', L'𞤏'},  // 0001e931 → 0001e90f
    {L'𞤲', L'𞤐'},  // 0001e932 → 0001e910
    {L'𞤳', L'𞤑'},  // 0001e933 → 0001e911
    {L'𞤴', L'𞤒'},  // 0001e934 → 0001e912
    {L'𞤵', L'𞤓'},  // 0001e935 → 0001e913
    {L'𞤶', L'𞤔'},  // 0001e936 → 0001e914
    {L'𞤷', L'𞤕'},  // 0001e937 → 0001e915
    {L'𞤸', L'𞤖'},  // 0001e938 → 0001e916
    {L'𞤹', L'𞤗'},  // 0001e939 → 0001e917
    {L'𞤺', L'𞤘'},  // 0001e93a → 0001e918
    {L'𞤻', L'𞤙'},  // 0001e93b → 0001e919
    {L'𞤼', L'𞤚'},  // 0001e93c → 0001e91a
    {L'𞤽', L'𞤛'},  // 0001e93d → 0001e91b
    {L'𞤾', L'𞤜'},  // 0001e93e → 0001e91c
    {L'𞤿', L'𞤝'},  // 0001e93f → 0001e91d
    {L'𞥀', L'𞤞'},  // 0001e940 → 0001e91e
    {L'𞥁', L'𞤟'},  // 0001e941 → 0001e91f
    {L'𞥂', L'𞤠'},  // 0001e942 → 0001e920
    {L'𞥃', L'𞤡'},  // 0001e943 → 0001e921
};

/**
 * Converts wide character to upper case.
 */
wint_t towupper(wint_t c) {
  int m, l, r;
  if (isascii(c)) return toupper(c);
  if (IsTiny() || c < 0x00010000) {
    l = 0;
    r = ARRAYLEN(kLowerToUpper) - 1;
    while (l <= r) {
      m = (l + r) >> 1;
      if (kLowerToUpper[m][0] < c) {
        l = m + 1;
      } else if (kLowerToUpper[m][0] > c) {
        r = m - 1;
      } else {
        return kLowerToUpper[m][1];
      }
    }
  } else {
    l = 0;
    r = ARRAYLEN(kLowerToUpperAstral) - 1;
    while (l <= r) {
      m = (l + r) >> 1;
      if (kLowerToUpperAstral[m][0] < c) {
        l = m + 1;
      } else if (kLowerToUpperAstral[m][0] > c) {
        r = m - 1;
      } else {
        return kLowerToUpperAstral[m][1];
      }
    }
  }
  return c;
}
